/*
 * Internal module API header file.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtQuickAPI_H
#define _QtQuickAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include <sip.h>

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_PLATFORM_WS_X11
#define SIP_TIMELINE_Qt_5_15_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QSGMaterialRhiShader__GraphicsPipelineState__ColorMaskComponent 0
#define sipName_QSGMaterialRhiShader__GraphicsPipelineState__ColorMaskComponent &sipStrings_QtQuick[0]
#define sipNameNr_QSGMaterialRhiShader__GraphicsPipelineState__BlendFactor 64
#define sipName_QSGMaterialRhiShader__GraphicsPipelineState__BlendFactor &sipStrings_QtQuick[64]
#define sipNameNr_QSGMaterialRhiShader__GraphicsPipelineState__ColorMask 121
#define sipName_QSGMaterialRhiShader__GraphicsPipelineState__ColorMask &sipStrings_QtQuick[121]
#define sipNameNr_QSGSimpleTextureNode__TextureCoordinatesTransformMode 176
#define sipName_QSGSimpleTextureNode__TextureCoordinatesTransformMode &sipStrings_QtQuick[176]
#define sipNameNr_QSGSimpleTextureNode__TextureCoordinatesTransformFlag 230
#define sipName_QSGSimpleTextureNode__TextureCoordinatesTransformFlag &sipStrings_QtQuick[230]
#define sipNameNr_QSGMaterialRhiShader__GraphicsPipelineState__CullMode 284
#define sipName_QSGMaterialRhiShader__GraphicsPipelineState__CullMode &sipStrings_QtQuick[284]
#define sipNameNr_QSGImageNode__TextureCoordinatesTransformMode 338
#define sipName_QSGImageNode__TextureCoordinatesTransformMode &sipStrings_QtQuick[338]
#define sipNameNr_QSGImageNode__TextureCoordinatesTransformFlag 384
#define sipName_QSGImageNode__TextureCoordinatesTransformFlag &sipStrings_QtQuick[384]
#define sipNameNr_QSGRendererInterface__ShaderCompilationTypes 430
#define sipName_QSGRendererInterface__ShaderCompilationTypes &sipStrings_QtQuick[430]
#define sipNameNr_QSGRendererInterface__ShaderCompilationType 475
#define sipName_QSGRendererInterface__ShaderCompilationType &sipStrings_QtQuick[475]
#define sipNameNr_QSGMaterialRhiShader__GraphicsPipelineState 519
#define sipName_QSGMaterialRhiShader__GraphicsPipelineState &sipStrings_QtQuick[519]
#define sipNameNr_QSGMaterialShader__RenderState__DirtyStates 563
#define sipName_QSGMaterialShader__RenderState__DirtyStates &sipStrings_QtQuick[563]
#define sipNameNr_QSGMaterialShader__RenderState__DirtyState 607
#define sipName_QSGMaterialShader__RenderState__DirtyState &sipStrings_QtQuick[607]
#define sipNameNr_QSGAbstractRenderer__MatrixTransformFlags 650
#define sipName_QSGAbstractRenderer__MatrixTransformFlags &sipStrings_QtQuick[650]
#define sipNameNr_QSGAbstractRenderer__MatrixTransformFlag 692
#define sipName_QSGAbstractRenderer__MatrixTransformFlag &sipStrings_QtQuick[692]
#define sipNameNr_QSGRendererInterface__ShaderSourceTypes 733
#define sipName_QSGRendererInterface__ShaderSourceTypes &sipStrings_QtQuick[733]
#define sipNameNr_QSGRendererInterface__ShaderSourceType 773
#define sipName_QSGRendererInterface__ShaderSourceType &sipStrings_QtQuick[773]
#define sipNameNr_QQuickPaintedItem__PerformanceHints 812
#define sipName_QQuickPaintedItem__PerformanceHints &sipStrings_QtQuick[812]
#define sipNameNr_QQuickWindow__CreateTextureOptions 848
#define sipName_QQuickWindow__CreateTextureOptions &sipStrings_QtQuick[848]
#define sipNameNr_QQuickPaintedItem__PerformanceHint 883
#define sipName_QQuickPaintedItem__PerformanceHint &sipStrings_QtQuick[883]
#define sipNameNr_QSGRendererInterface__GraphicsApi 918
#define sipName_QSGRendererInterface__GraphicsApi &sipStrings_QtQuick[918]
#define sipNameNr_QSGMaterialRhiShader__RenderState 952
#define sipName_QSGMaterialRhiShader__RenderState &sipStrings_QtQuick[952]
#define sipNameNr_RequiresFullMatrixExceptTranslate 986
#define sipName_RequiresFullMatrixExceptTranslate &sipStrings_QtQuick[986]
#define sipNameNr_defaultAttributes_TexturedPoint2D 1020
#define sipName_defaultAttributes_TexturedPoint2D &sipStrings_QtQuick[1020]
#define sipNameNr_QSGAbstractRenderer__ClearModeBit 1054
#define sipName_QSGAbstractRenderer__ClearModeBit &sipStrings_QtQuick[1054]
#define sipNameNr_QQuickWindow__CreateTextureOption 1088
#define sipName_QQuickWindow__CreateTextureOption &sipStrings_QtQuick[1088]
#define sipNameNr_QQuickFramebufferObject__Renderer 1122
#define sipName_QQuickFramebufferObject__Renderer &sipStrings_QtQuick[1122]
#define sipNameNr_QSGRendererInterface__ShaderType 1156
#define sipName_QSGRendererInterface__ShaderType &sipStrings_QtQuick[1156]
#define sipNameNr_defaultAttributes_ColoredPoint2D 1189
#define sipName_defaultAttributes_ColoredPoint2D &sipStrings_QtQuick[1189]
#define sipNameNr_TextureCoordinatesTransformMode 198
#define sipName_TextureCoordinatesTransformMode &sipStrings_QtQuick[198]
#define sipNameNr_TextureCoordinatesTransformFlag 252
#define sipName_TextureCoordinatesTransformFlag &sipStrings_QtQuick[252]
#define sipNameNr_QSGEngine__CreateTextureOptions 1222
#define sipName_QSGEngine__CreateTextureOptions &sipStrings_QtQuick[1222]
#define sipNameNr_QQuickPaintedItem__RenderTarget 1254
#define sipName_QQuickPaintedItem__RenderTarget &sipStrings_QtQuick[1254]
#define sipNameNr_QQuickItem__UpdatePaintNodeData 1286
#define sipName_QQuickItem__UpdatePaintNodeData &sipStrings_QtQuick[1286]
#define sipNameNr_QSGRendererInterface__Resource 1318
#define sipName_QSGRendererInterface__Resource &sipStrings_QtQuick[1318]
#define sipNameNr_QSGMaterialShader__RenderState 1349
#define sipName_QSGMaterialShader__RenderState &sipStrings_QtQuick[1349]
#define sipNameNr_setTextureCoordinatesTransform 1380
#define sipName_setTextureCoordinatesTransform &sipStrings_QtQuick[1380]
#define sipNameNr_QSGEngine__CreateTextureOption 1411
#define sipName_QSGEngine__CreateTextureOption &sipStrings_QtQuick[1411]
#define sipNameNr_QSGAbstractRenderer__ClearMode 1442
#define sipName_QSGAbstractRenderer__ClearMode &sipStrings_QtQuick[1442]
#define sipNameNr_QQuickWindow__NativeObjectType 1473
#define sipName_QQuickWindow__NativeObjectType &sipStrings_QtQuick[1473]
#define sipNameNr_ItemDevicePixelRatioHasChanged 1504
#define sipName_ItemDevicePixelRatioHasChanged &sipStrings_QtQuick[1504]
#define sipNameNr_convertToNormalizedSourceRect 1535
#define sipName_convertToNormalizedSourceRect &sipStrings_QtQuick[1535]
#define sipNameNr_QSGRenderNode__RenderingFlags 1565
#define sipName_QSGRenderNode__RenderingFlags &sipStrings_QtQuick[1565]
#define sipNameNr_QQuickWindow__SceneGraphError 1595
#define sipName_QQuickWindow__SceneGraphError &sipStrings_QtQuick[1595]
#define sipNameNr_createTextureFromNativeObject 1625
#define sipName_createTextureFromNativeObject &sipStrings_QtQuick[1625]
#define sipNameNr_textureFollowsItemSizeChanged 1655
#define sipName_textureFollowsItemSizeChanged &sipStrings_QtQuick[1655]
#define sipNameNr_QSGRenderNode__RenderingFlag 1685
#define sipName_QSGRenderNode__RenderingFlag &sipStrings_QtQuick[1685]
#define sipNameNr_UpdatesGraphicsPipelineState 1714
#define sipName_UpdatesGraphicsPipelineState &sipStrings_QtQuick[1714]
#define sipNameNr_QSGGeometry__TexturedPoint2D 1743
#define sipName_QSGGeometry__TexturedPoint2D &sipStrings_QtQuick[1743]
#define sipNameNr_QQuickWindow__TextRenderType 1772
#define sipName_QQuickWindow__TextRenderType &sipStrings_QtQuick[1772]
#define sipNameNr_QSGTexture__AnisotropyLevel 1801
#define sipName_QSGTexture__AnisotropyLevel &sipStrings_QtQuick[1801]
#define sipNameNr_updateGraphicsPipelineState 1829
#define sipName_updateGraphicsPipelineState &sipStrings_QtQuick[1829]
#define sipNameNr_QSGMaterialRhiShader__Flags 1857
#define sipName_QSGMaterialRhiShader__Flags &sipStrings_QtQuick[1857]
#define sipNameNr_textureCoordinatesTransform 1885
#define sipName_textureCoordinatesTransform &sipStrings_QtQuick[1885]
#define sipNameNr_vertexDataAsTexturedPoint2D 1913
#define sipName_vertexDataAsTexturedPoint2D &sipStrings_QtQuick[1913]
#define sipNameNr_QSGGeometry__ColoredPoint2D 1941
#define sipName_QSGGeometry__ColoredPoint2D &sipStrings_QtQuick[1941]
#define sipNameNr_QQuickItem__TransformOrigin 1969
#define sipName_QQuickItem__TransformOrigin &sipStrings_QtQuick[1969]
#define sipNameNr_invalidateFramebufferObject 1997
#define sipName_invalidateFramebufferObject &sipStrings_QtQuick[1997]
#define sipNameNr_QSGRenderNode__RenderState 2025
#define sipName_QSGRenderNode__RenderState &sipStrings_QtQuick[2025]
#define sipNameNr_QSGMaterialRhiShader__Flag 2052
#define sipName_QSGMaterialRhiShader__Flag &sipStrings_QtQuick[2052]
#define sipNameNr_QSGGeometry__AttributeType 2079
#define sipName_QSGGeometry__AttributeType &sipStrings_QtQuick[2079]
#define sipNameNr_vertexDataAsColoredPoint2D 2106
#define sipName_vertexDataAsColoredPoint2D &sipStrings_QtQuick[2106]
#define sipNameNr_updateTexturedRectGeometry 2133
#define sipName_updateTexturedRectGeometry &sipStrings_QtQuick[2133]
#define sipNameNr_setPersistentOpenGLContext 2160
#define sipName_setPersistentOpenGLContext &sipStrings_QtQuick[2160]
#define sipNameNr_InvertedYFramebufferObject 2187
#define sipName_InvertedYFramebufferObject &sipStrings_QtQuick[2187]
#define sipNameNr_setFiltersChildMouseEvents 2214
#define sipName_setFiltersChildMouseEvents &sipStrings_QtQuick[2214]
#define sipNameNr_QQuickItem__ItemChangeData 2241
#define sipName_QQuickItem__ItemChangeData &sipStrings_QtQuick[2241]
#define sipNameNr_ItemAntialiasingHasChanged 2268
#define sipName_ItemAntialiasingHasChanged &sipStrings_QtQuick[2268]
#define sipNameNr_QSGTexture__NativeTexture 2295
#define sipName_QSGTexture__NativeTexture &sipStrings_QtQuick[2295]
#define sipNameNr_QSGRenderNode__StateFlags 2321
#define sipName_QSGRenderNode__StateFlags &sipStrings_QtQuick[2321]
#define sipNameNr_isCachedMaterialDataDirty 2347
#define sipName_isCachedMaterialDataDirty &sipStrings_QtQuick[2347]
#define sipNameNr_updateColoredRectGeometry 2373
#define sipName_updateColoredRectGeometry &sipStrings_QtQuick[2373]
#define sipNameNr_defaultAttributes_Point2D 2399
#define sipName_defaultAttributes_Point2D &sipStrings_QtQuick[2399]
#define sipNameNr_QSGGeometry__AttributeSet 2425
#define sipName_QSGGeometry__AttributeSet &sipStrings_QtQuick[2425]
#define sipNameNr_setProjectionMatrixToRect 2451
#define sipName_setProjectionMatrixToRect &sipStrings_QtQuick[2451]
#define sipNameNr_beforeRenderPassRecording 2477
#define sipName_beforeRenderPassRecording &sipStrings_QtQuick[2477]
#define sipNameNr_effectiveDevicePixelRatio 2503
#define sipName_effectiveDevicePixelRatio &sipStrings_QtQuick[2503]
#define sipNameNr_QQuickWindow__RenderStage 2529
#define sipName_QQuickWindow__RenderStage &sipStrings_QtQuick[2529]
#define sipNameNr_isPersistentOpenGLContext 2555
#define sipName_isPersistentOpenGLContext &sipStrings_QtQuick[2555]
#define sipNameNr_ItemActiveFocusHasChanged 2581
#define sipName_ItemActiveFocusHasChanged &sipStrings_QtQuick[2581]
#define sipNameNr_setTextureFollowsItemSize 2607
#define sipName_setTextureFollowsItemSize &sipStrings_QtQuick[2607]
#define sipNameNr_QSGOpaqueTextureMaterial 2633
#define sipName_QSGOpaqueTextureMaterial &sipStrings_QtQuick[2633]
#define sipNameNr_normalizedTextureSubRect 2658
#define sipName_normalizedTextureSubRect &sipStrings_QtQuick[2658]
#define sipNameNr_QSGRenderNode__StateFlag 2683
#define sipName_QSGRenderNode__StateFlag &sipStrings_QtQuick[2683]
#define sipNameNr_QSGGeometry__DrawingMode 2708
#define sipName_QSGGeometry__DrawingMode &sipStrings_QtQuick[2708]
#define sipNameNr_QSGGeometry__DataPattern 2733
#define sipName_QSGGeometry__DataPattern &sipStrings_QtQuick[2733]
#define sipNameNr_afterRenderPassRecording 2758
#define sipName_afterRenderPassRecording &sipStrings_QtQuick[2758]
#define sipNameNr_BeforeSynchronizingStage 2783
#define sipName_BeforeSynchronizingStage &sipStrings_QtQuick[2783]
#define sipNameNr_ItemClipsChildrenToShape 2808
#define sipName_ItemClipsChildrenToShape &sipStrings_QtQuick[2808]
#define sipNameNr_QQuickAsyncImageProvider 2833
#define sipName_QQuickAsyncImageProvider &sipStrings_QtQuick[2833]
#define sipNameNr_DirtyCachedMaterialData 2858
#define sipName_DirtyCachedMaterialData &sipStrings_QtQuick[2858]
#define sipNameNr_createWithAttributeType 2882
#define sipName_createWithAttributeType &sipStrings_QtQuick[2882]
#define sipNameNr_isSceneGraphInitialized 2906
#define sipName_isSceneGraphInitialized &sipStrings_QtQuick[2906]
#define sipNameNr_AfterSynchronizingStage 2930
#define sipName_AfterSynchronizingStage &sipStrings_QtQuick[2930]
#define sipNameNr_setPersistentSceneGraph 2954
#define sipName_setPersistentSceneGraph &sipStrings_QtQuick[2954]
#define sipNameNr_setClearBeforeRendering 2978
#define sipName_setClearBeforeRendering &sipStrings_QtQuick[2978]
#define sipNameNr_filtersChildMouseEvents 3002
#define sipName_filtersChildMouseEvents &sipStrings_QtQuick[3002]
#define sipNameNr_setAcceptedMouseButtons 3026
#define sipName_setAcceptedMouseButtons &sipStrings_QtQuick[3026]
#define sipNameNr_mirrorVerticallyChanged 3050
#define sipName_mirrorVerticallyChanged &sipStrings_QtQuick[3050]
#define sipNameNr_createFramebufferObject 3074
#define sipName_createFramebufferObject &sipStrings_QtQuick[3074]
#define sipNameNr_QQuickFramebufferObject 3098
#define sipName_QQuickFramebufferObject &sipStrings_QtQuick[3098]
#define sipNameNr_QSGVertexColorMaterial 3122
#define sipName_QSGVertexColorMaterial &sipStrings_QtQuick[3122]
#define sipNameNr_ShaderCompilationTypes 452
#define sipName_ShaderCompilationTypes &sipStrings_QtQuick[452]
#define sipNameNr_UnknownShadingLanguage 3145
#define sipName_UnknownShadingLanguage &sipStrings_QtQuick[3145]
#define sipNameNr_VulkanInstanceResource 3168
#define sipName_VulkanInstanceResource &sipStrings_QtQuick[3168]
#define sipNameNr_CommandEncoderResource 3191
#define sipName_CommandEncoderResource &sipStrings_QtQuick[3191]
#define sipNameNr_PhysicalDeviceResource 3214
#define sipName_PhysicalDeviceResource &sipStrings_QtQuick[3214]
#define sipNameNr_QSGNode__DirtyStateBit 3237
#define sipName_QSGNode__DirtyStateBit &sipStrings_QtQuick[3237]
#define sipNameNr_QSGGeometry__Attribute 3260
#define sipName_QSGGeometry__Attribute &sipStrings_QtQuick[3260]
#define sipNameNr_activeFocusItemChanged 3283
#define sipName_activeFocusItemChanged &sipStrings_QtQuick[3283]
#define sipNameNr_isPersistentSceneGraph 3306
#define sipName_isPersistentSceneGraph &sipStrings_QtQuick[3306]
#define sipNameNr_createTextureFromImage 3329
#define sipName_createTextureFromImage &sipStrings_QtQuick[3329]
#define sipNameNr_TextureHasAlphaChannel 3352
#define sipName_TextureHasAlphaChannel &sipStrings_QtQuick[3352]
#define sipNameNr_QQuickView__ResizeMode 3375
#define sipName_QQuickView__ResizeMode &sipStrings_QtQuick[3375]
#define sipNameNr_containmentMaskChanged 3398
#define sipName_containmentMaskChanged &sipStrings_QtQuick[3398]
#define sipNameNr_ItemRotationHasChanged 3421
#define sipName_ItemRotationHasChanged &sipStrings_QtQuick[3421]
#define sipNameNr_ItemChildRemovedChange 3444
#define sipName_ItemChildRemovedChange &sipStrings_QtQuick[3444]
#define sipNameNr_QQuickItem__ItemChange 3467
#define sipName_QQuickItem__ItemChange &sipStrings_QtQuick[3467]
#define sipNameNr_ItemAcceptsInputMethod 3490
#define sipName_ItemAcceptsInputMethod &sipStrings_QtQuick[3490]
#define sipNameNr_textureFactoryForImage 3513
#define sipName_textureFactoryForImage &sipStrings_QtQuick[3513]
#define sipNameNr_textureFollowsItemSize 3536
#define sipName_textureFollowsItemSize &sipStrings_QtQuick[3536]
#define sipNameNr_setHorizontalWrapMode 3559
#define sipName_setHorizontalWrapMode &sipStrings_QtQuick[3559]
#define sipNameNr_QSGTexture__Filtering 3581
#define sipName_QSGTexture__Filtering &sipStrings_QtQuick[3581]
#define sipNameNr_shaderCompilationType 3603
#define sipName_shaderCompilationType &sipStrings_QtQuick[3603]
#define sipNameNr_ShaderCompilationType 497
#define sipName_ShaderCompilationType &sipStrings_QtQuick[497]
#define sipNameNr_DeviceContextResource 3625
#define sipName_DeviceContextResource &sipStrings_QtQuick[3625]
#define sipNameNr_OpenGLContextResource 3647
#define sipName_OpenGLContextResource &sipStrings_QtQuick[3647]
#define sipNameNr_insertChildNodeBefore 3669
#define sipName_insertChildNodeBefore &sipStrings_QtQuick[3669]
#define sipNameNr_OneMinusConstantAlpha 3691
#define sipName_OneMinusConstantAlpha &sipStrings_QtQuick[3691]
#define sipNameNr_OneMinusConstantColor 3713
#define sipName_OneMinusConstantColor &sipStrings_QtQuick[3713]
#define sipNameNr_GraphicsPipelineState 541
#define sipName_GraphicsPipelineState &sipStrings_QtQuick[541]
#define sipNameNr_beginExternalCommands 3735
#define sipName_beginExternalCommands &sipStrings_QtQuick[3735]
#define sipNameNr_sceneGraphAboutToStop 3757
#define sipName_sceneGraphAboutToStop &sipStrings_QtQuick[3757]
#define sipNameNr_setDefaultAlphaBuffer 3779
#define sipName_setDefaultAlphaBuffer &sipStrings_QtQuick[3779]
#define sipNameNr_hasDefaultAlphaBuffer 3801
#define sipName_hasDefaultAlphaBuffer &sipStrings_QtQuick[3801]
#define sipNameNr_sceneGraphInvalidated 3823
#define sipName_sceneGraphInvalidated &sipStrings_QtQuick[3823]
#define sipNameNr_sceneGraphInitialized 3845
#define sipName_sceneGraphInitialized &sipStrings_QtQuick[3845]
#define sipNameNr_childMouseEventFilter 3867
#define sipName_childMouseEventFilter &sipStrings_QtQuick[3867]
#define sipNameNr_ItemEnabledHasChanged 3889
#define sipName_ItemEnabledHasChanged &sipStrings_QtQuick[3889]
#define sipNameNr_ItemOpacityHasChanged 3911
#define sipName_ItemOpacityHasChanged &sipStrings_QtQuick[3911]
#define sipNameNr_ItemVisibleHasChanged 3933
#define sipName_ItemVisibleHasChanged &sipStrings_QtQuick[3933]
#define sipNameNr_mouseDoubleClickEvent 3955
#define sipName_mouseDoubleClickEvent &sipStrings_QtQuick[3955]
#define sipNameNr_QSGTexture__WrapMode 3977
#define sipName_QSGTexture__WrapMode &sipStrings_QtQuick[3977]
#define sipNameNr_QSGSimpleTextureNode 3998
#define sipName_QSGSimpleTextureNode &sipStrings_QtQuick[3998]
#define sipNameNr_BoundedRectRendering 4019
#define sipName_BoundedRectRendering &sipStrings_QtQuick[4019]
#define sipNameNr_CommandQueueResource 4040
#define sipName_CommandQueueResource &sipStrings_QtQuick[4040]
#define sipNameNr_QSGRendererInterface 4061
#define sipName_QSGRendererInterface &sipStrings_QtQuick[4061]
#define sipNameNr_QSGBasicGeometryNode 4082
#define sipName_QSGBasicGeometryNode &sipStrings_QtQuick[4082]
#define sipNameNr_insertChildNodeAfter 4103
#define sipName_insertChildNodeAfter &sipStrings_QtQuick[4103]
#define sipNameNr_QSGMaterialRhiShader 4124
#define sipName_QSGMaterialRhiShader &sipStrings_QtQuick[4124]
#define sipNameNr_setShaderSourceFiles 4145
#define sipName_setShaderSourceFiles &sipStrings_QtQuick[4145]
#define sipNameNr_setVertexDataPattern 4166
#define sipName_setVertexDataPattern &sipStrings_QtQuick[4166]
#define sipNameNr_QSGGeometry__Point2D 4187
#define sipName_QSGGeometry__Point2D &sipStrings_QtQuick[4187]
#define sipNameNr_QSGFlatColorMaterial 4208
#define sipName_QSGFlatColorMaterial &sipStrings_QtQuick[4208]
#define sipNameNr_MatrixTransformFlags 671
#define sipName_MatrixTransformFlags &sipStrings_QtQuick[671]
#define sipNameNr_MatrixTransformFlipY 4229
#define sipName_MatrixTransformFlipY &sipStrings_QtQuick[4229]
#define sipNameNr_setSceneGraphBackend 4250
#define sipName_setSceneGraphBackend &sipStrings_QtQuick[4250]
#define sipNameNr_BeforeRenderingStage 4271
#define sipName_BeforeRenderingStage &sipStrings_QtQuick[4271]
#define sipNameNr_openglContextCreated 4292
#define sipName_openglContextCreated &sipStrings_QtQuick[4292]
#define sipNameNr_clearBeforeRendering 4313
#define sipName_clearBeforeRendering &sipStrings_QtQuick[4313]
#define sipNameNr_CreateTextureOptions 862
#define sipName_CreateTextureOptions &sipStrings_QtQuick[862]
#define sipNameNr_TextureOwnsGLTexture 4334
#define sipName_TextureOwnsGLTexture &sipStrings_QtQuick[4334]
#define sipNameNr_SizeRootObjectToView 4355
#define sipName_SizeRootObjectToView &sipStrings_QtQuick[4355]
#define sipNameNr_SizeViewToRootObject 4376
#define sipName_SizeViewToRootObject &sipStrings_QtQuick[4376]
#define sipNameNr_contentsScaleChanged 4397
#define sipName_contentsScaleChanged &sipStrings_QtQuick[4397]
#define sipNameNr_contentsBoundingRect 4418
#define sipName_contentsBoundingRect &sipStrings_QtQuick[4418]
#define sipNameNr_QQuickItemGrabResult 4439
#define sipName_QQuickItemGrabResult &sipStrings_QtQuick[4439]
#define sipNameNr_setAcceptTouchEvents 4460
#define sipName_setAcceptTouchEvents &sipStrings_QtQuick[4460]
#define sipNameNr_nextItemInFocusChain 4481
#define sipName_nextItemInFocusChain &sipStrings_QtQuick[4481]
#define sipNameNr_setAcceptHoverEvents 4502
#define sipName_setAcceptHoverEvents &sipStrings_QtQuick[4502]
#define sipNameNr_acceptedMouseButtons 4523
#define sipName_acceptedMouseButtons &sipStrings_QtQuick[4523]
#define sipNameNr_ItemParentHasChanged 4544
#define sipName_ItemParentHasChanged &sipStrings_QtQuick[4544]
#define sipNameNr_ItemChildAddedChange 4565
#define sipName_ItemChildAddedChange &sipStrings_QtQuick[4565]
#define sipNameNr_requestImageResponse 4586
#define sipName_requestImageResponse &sipStrings_QtQuick[4586]
#define sipNameNr_QQuickTextureFactory 4607
#define sipName_QQuickTextureFactory &sipStrings_QtQuick[4607]
#define sipNameNr_incubationController 4628
#define sipName_incubationController &sipStrings_QtQuick[4628]
#define sipNameNr_setInitialProperties 4649
#define sipName_setInitialProperties &sipStrings_QtQuick[4649]
#define sipNameNr_setVerticalWrapMode 4670
#define sipName_setVerticalWrapMode &sipStrings_QtQuick[4670]
#define sipNameNr_DepthAwareRendering 4690
#define sipName_DepthAwareRendering &sipStrings_QtQuick[4690]
#define sipNameNr_CommandListResource 4710
#define sipName_CommandListResource &sipStrings_QtQuick[4710]
#define sipNameNr_removeAllChildNodes 4730
#define sipName_removeAllChildNodes &sipStrings_QtQuick[4730]
#define sipNameNr_QSGNode__DirtyState 4750
#define sipName_QSGNode__DirtyState &sipStrings_QtQuick[4750]
#define sipNameNr_RequiresDeterminant 4770
#define sipName_RequiresDeterminant &sipStrings_QtQuick[4770]
#define sipNameNr_setShaderSourceFile 4790
#define sipName_setShaderSourceFile &sipStrings_QtQuick[4790]
#define sipNameNr_vertexDataAsPoint2D 4810
#define sipName_vertexDataAsPoint2D &sipStrings_QtQuick[4810]
#define sipNameNr_markVertexDataDirty 4830
#define sipName_markVertexDataDirty &sipStrings_QtQuick[4830]
#define sipNameNr_setIndexDataPattern 4850
#define sipName_setIndexDataPattern &sipStrings_QtQuick[4850]
#define sipNameNr_AlwaysUploadPattern 4870
#define sipName_AlwaysUploadPattern &sipStrings_QtQuick[4870]
#define sipNameNr_setProjectionMatrix 4890
#define sipName_setProjectionMatrix &sipStrings_QtQuick[4890]
#define sipNameNr_MatrixTransformFlag 713
#define sipName_MatrixTransformFlag &sipStrings_QtQuick[713]
#define sipNameNr_QSGAbstractRenderer 4910
#define sipName_QSGAbstractRenderer &sipStrings_QtQuick[4910]
#define sipNameNr_endExternalCommands 4930
#define sipName_endExternalCommands &sipStrings_QtQuick[4930]
#define sipNameNr_NativeObjectTexture 4950
#define sipName_NativeObjectTexture &sipStrings_QtQuick[4950]
#define sipNameNr_NativeTextRendering 4970
#define sipName_NativeTextRendering &sipStrings_QtQuick[4970]
#define sipNameNr_createRectangleNode 4990
#define sipName_createRectangleNode &sipStrings_QtQuick[4990]
#define sipNameNr_AfterRenderingStage 5010
#define sipName_AfterRenderingStage &sipStrings_QtQuick[5010]
#define sipNameNr_ContextNotAvailable 5030
#define sipName_ContextNotAvailable &sipStrings_QtQuick[5030]
#define sipNameNr_beforeSynchronizing 5050
#define sipName_beforeSynchronizing &sipStrings_QtQuick[5050]
#define sipNameNr_createTextureFromId 5070
#define sipName_createTextureFromId &sipStrings_QtQuick[5070]
#define sipNameNr_CreateTextureOption 1102
#define sipName_CreateTextureOption &sipStrings_QtQuick[1102]
#define sipNameNr_QQuickRenderControl 5090
#define sipName_QQuickRenderControl &sipStrings_QtQuick[5090]
#define sipNameNr_renderTargetChanged 5110
#define sipName_renderTargetChanged &sipStrings_QtQuick[5110]
#define sipNameNr_contentsSizeChanged 5130
#define sipName_contentsSizeChanged &sipStrings_QtQuick[5130]
#define sipNameNr_setPerformanceHints 5150
#define sipName_setPerformanceHints &sipStrings_QtQuick[5150]
#define sipNameNr_setActiveFocusOnTab 5170
#define sipName_setActiveFocusOnTab &sipStrings_QtQuick[5170]
#define sipNameNr_isComponentComplete 5190
#define sipName_isComponentComplete &sipStrings_QtQuick[5190]
#define sipNameNr_UpdatePaintNodeData 1298
#define sipName_UpdatePaintNodeData &sipStrings_QtQuick[1298]
#define sipNameNr_QQuickImageResponse 5210
#define sipName_QQuickImageResponse &sipStrings_QtQuick[5210]
#define sipNameNr_QQuickImageProvider 5230
#define sipName_QQuickImageProvider &sipStrings_QtQuick[5230]
#define sipNameNr_setMirrorVertically 5250
#define sipName_setMirrorVertically &sipStrings_QtQuick[5250]
#define sipNameNr_5270 5270
#define sipName_5270 &sipStrings_QtQuick[5270]
#define sipNameNr_QSGTextureProvider 5289
#define sipName_QSGTextureProvider &sipStrings_QtQuick[5289]
#define sipNameNr_QSGTextureMaterial 5308
#define sipName_QSGTextureMaterial &sipStrings_QtQuick[5308]
#define sipNameNr_setAnisotropyLevel 5327
#define sipName_setAnisotropyLevel &sipStrings_QtQuick[5327]
#define sipNameNr_horizontalWrapMode 5346
#define sipName_horizontalWrapMode &sipStrings_QtQuick[5346]
#define sipNameNr_ShaderSourceString 5365
#define sipName_ShaderSourceString &sipStrings_QtQuick[5365]
#define sipNameNr_OfflineCompilation 5384
#define sipName_OfflineCompilation &sipStrings_QtQuick[5384]
#define sipNameNr_RuntimeCompilation 5403
#define sipName_RuntimeCompilation &sipStrings_QtQuick[5403]
#define sipNameNr_RenderPassResource 5422
#define sipName_RenderPassResource &sipStrings_QtQuick[5422]
#define sipNameNr_OwnsOpaqueMaterial 5441
#define sipName_OwnsOpaqueMaterial &sipStrings_QtQuick[5441]
#define sipNameNr_updateSampledImage 5460
#define sipName_updateSampledImage &sipStrings_QtQuick[5460]
#define sipNameNr_ColorMaskComponent 45
#define sipName_ColorMaskComponent &sipStrings_QtQuick[45]
#define sipNameNr_QSGMaterial__Flags 5479
#define sipName_QSGMaterial__Flags &sipStrings_QtQuick[5479]
#define sipNameNr_RequiresFullMatrix 5498
#define sipName_RequiresFullMatrix &sipStrings_QtQuick[5498]
#define sipNameNr_MirrorHorizontally 5517
#define sipName_MirrorHorizontally &sipStrings_QtQuick[5517]
#define sipNameNr_setMipmapFiltering 5536
#define sipName_setMipmapFiltering &sipStrings_QtQuick[5536]
#define sipNameNr_TexCoord2Attribute 5555
#define sipName_TexCoord2Attribute &sipStrings_QtQuick[5555]
#define sipNameNr_TexCoord1Attribute 5574
#define sipName_TexCoord1Attribute &sipStrings_QtQuick[5574]
#define sipNameNr_markIndexDataDirty 5593
#define sipName_markIndexDataDirty &sipStrings_QtQuick[5593]
#define sipNameNr_updateRectGeometry 5612
#define sipName_updateRectGeometry &sipStrings_QtQuick[5612]
#define sipNameNr_isVertexCoordinate 5631
#define sipName_isVertexCoordinate &sipStrings_QtQuick[5631]
#define sipNameNr_ClearStencilBuffer 5650
#define sipName_ClearStencilBuffer &sipStrings_QtQuick[5650]
#define sipNameNr_afterSynchronizing 5669
#define sipName_afterSynchronizing &sipStrings_QtQuick[5669]
#define sipNameNr_TextureCanUseAtlas 5688
#define sipName_TextureCanUseAtlas &sipStrings_QtQuick[5688]
#define sipNameNr_QQuickView__Status 5707
#define sipName_QQuickView__Status &sipStrings_QtQuick[5707]
#define sipNameNr_QQuickTextDocument 5726
#define sipName_QQuickTextDocument &sipStrings_QtQuick[5726]
#define sipNameNr_textureSizeChanged 5745
#define sipName_textureSizeChanged &sipStrings_QtQuick[5745]
#define sipNameNr_setContainmentMask 5764
#define sipName_setContainmentMask &sipStrings_QtQuick[5764]
#define sipNameNr_setTransformOrigin 5783
#define sipName_setTransformOrigin &sipStrings_QtQuick[5783]
#define sipNameNr_setPerformanceHint 5802
#define sipName_setPerformanceHint &sipStrings_QtQuick[5802]
#define sipNameNr_QSGDynamicTexture 5821
#define sipName_QSGDynamicTexture &sipStrings_QtQuick[5821]
#define sipNameNr_updateBindOptions 5839
#define sipName_updateBindOptions &sipStrings_QtQuick[5839]
#define sipNameNr_QSGSimpleRectNode 5857
#define sipName_QSGSimpleRectNode &sipStrings_QtQuick[5857]
#define sipNameNr_RenderTargetState 5875
#define sipName_RenderTargetState &sipStrings_QtQuick[5875]
#define sipNameNr_ShaderSourceTypes 755
#define sipName_ShaderSourceTypes &sipStrings_QtQuick[755]
#define sipNameNr_setOpaqueMaterial 5893
#define sipName_setOpaqueMaterial &sipStrings_QtQuick[5893]
#define sipNameNr_TransformNodeType 5911
#define sipName_TransformNodeType &sipStrings_QtQuick[5911]
#define sipNameNr_QSGNode__NodeType 5929
#define sipName_QSGNode__NodeType &sipStrings_QtQuick[5929]
#define sipNameNr_updateUniformData 5947
#define sipName_updateUniformData &sipStrings_QtQuick[5947]
#define sipNameNr_OneMinusSrc1Alpha 5965
#define sipName_OneMinusSrc1Alpha &sipStrings_QtQuick[5965]
#define sipNameNr_OneMinusSrc1Color 5983
#define sipName_OneMinusSrc1Color &sipStrings_QtQuick[5983]
#define sipNameNr_SupportsRhiShader 6001
#define sipName_SupportsRhiShader &sipStrings_QtQuick[6001]
#define sipNameNr_CustomCompileStep 6019
#define sipName_CustomCompileStep &sipStrings_QtQuick[6019]
#define sipNameNr_QSGMaterial__Flag 6037
#define sipName_QSGMaterial__Flag &sipStrings_QtQuick[6037]
#define sipNameNr_QSGMaterialShader 6055
#define sipName_QSGMaterialShader &sipStrings_QtQuick[6055]
#define sipNameNr_UnsignedShortType 6073
#define sipName_UnsignedShortType &sipStrings_QtQuick[6073]
#define sipNameNr_QSGGeometry__Type 6091
#define sipName_QSGGeometry__Type &sipStrings_QtQuick[6091]
#define sipNameNr_DrawTriangleStrip 6109
#define sipName_DrawTriangleStrip &sipStrings_QtQuick[6109]
#define sipNameNr_TexCoordAttribute 6127
#define sipName_TexCoordAttribute &sipStrings_QtQuick[6127]
#define sipNameNr_PositionAttribute 6145
#define sipName_PositionAttribute &sipStrings_QtQuick[6145]
#define sipNameNr_indexDataAsUShort 6163
#define sipName_indexDataAsUShort &sipStrings_QtQuick[6163]
#define sipNameNr_vertexDataPattern 6181
#define sipName_vertexDataPattern &sipStrings_QtQuick[6181]
#define sipNameNr_GL_TRIANGLE_STRIP 6199
#define sipName_GL_TRIANGLE_STRIP &sipStrings_QtQuick[6199]
#define sipNameNr_sceneGraphChanged 6217
#define sipName_sceneGraphChanged &sipStrings_QtQuick[6217]
#define sipNameNr_setTextRenderType 6235
#define sipName_setTextRenderType &sipStrings_QtQuick[6235]
#define sipNameNr_sceneGraphBackend 6253
#define sipName_sceneGraphBackend &sipStrings_QtQuick[6253]
#define sipNameNr_rendererInterface 6271
#define sipName_rendererInterface &sipStrings_QtQuick[6271]
#define sipNameNr_scheduleRenderJob 6289
#define sipName_scheduleRenderJob &sipStrings_QtQuick[6289]
#define sipNameNr_TextureHasMipmaps 6307
#define sipName_TextureHasMipmaps &sipStrings_QtQuick[6307]
#define sipNameNr_resetContentsSize 6325
#define sipName_resetContentsSize &sipStrings_QtQuick[6325]
#define sipNameNr_setOpaquePainting 6343
#define sipName_setOpaquePainting &sipStrings_QtQuick[6343]
#define sipNameNr_FramebufferObject 2007
#define sipName_FramebufferObject &sipStrings_QtQuick[2007]
#define sipNameNr_QQuickPaintedItem 6361
#define sipName_QQuickPaintedItem &sipStrings_QtQuick[6361]
#define sipNameNr_acceptTouchEvents 6379
#define sipName_acceptTouchEvents &sipStrings_QtQuick[6379]
#define sipNameNr_resetAntialiasing 6397
#define sipName_resetAntialiasing &sipStrings_QtQuick[6397]
#define sipNameNr_updateInputMethod 6415
#define sipName_updateInputMethod &sipStrings_QtQuick[6415]
#define sipNameNr_ungrabTouchPoints 6433
#define sipName_ungrabTouchPoints &sipStrings_QtQuick[6433]
#define sipNameNr_acceptHoverEvents 6451
#define sipName_acceptHoverEvents &sipStrings_QtQuick[6451]
#define sipNameNr_setImplicitHeight 6469
#define sipName_setImplicitHeight &sipStrings_QtQuick[6469]
#define sipNameNr_setBaselineOffset 6487
#define sipName_setBaselineOffset &sipStrings_QtQuick[6487]
#define sipNameNr_QQuickItem__Flags 6505
#define sipName_QQuickItem__Flags &sipStrings_QtQuick[6505]
#define sipNameNr_isTextureProvider 6523
#define sipName_isTextureProvider &sipStrings_QtQuick[6523]
#define sipNameNr_framebufferObject 6541
#define sipName_framebufferObject &sipStrings_QtQuick[6541]
#define sipNameNr_componentComplete 6559
#define sipName_componentComplete &sipStrings_QtQuick[6559]
#define sipNameNr_mouseReleaseEvent 6577
#define sipName_mouseReleaseEvent &sipStrings_QtQuick[6577]
#define sipNameNr_sip_simplewrapper 6595
#define sipName_sip_simplewrapper &sipStrings_QtQuick[6595]
#define sipNameNr_verticalWrapMode 6613
#define sipName_verticalWrapMode &sipStrings_QtQuick[6613]
#define sipNameNr_removedFromAtlas 6630
#define sipName_removedFromAtlas &sipStrings_QtQuick[6630]
#define sipNameNr_inheritedOpacity 6647
#define sipName_inheritedOpacity &sipStrings_QtQuick[6647]
#define sipNameNr_shaderSourceType 6664
#define sipName_shaderSourceType &sipStrings_QtQuick[6664]
#define sipNameNr_ShaderSourceFile 4793
#define sipName_ShaderSourceFile &sipStrings_QtQuick[4793]
#define sipNameNr_ShaderSourceType 795
#define sipName_ShaderSourceType &sipStrings_QtQuick[795]
#define sipNameNr_QSGRectangleNode 6681
#define sipName_QSGRectangleNode &sipStrings_QtQuick[6681]
#define sipNameNr_QSGTransformNode 6698
#define sipName_QSGTransformNode &sipStrings_QtQuick[6698]
#define sipNameNr_setIsRectangular 6715
#define sipName_setIsRectangular &sipStrings_QtQuick[6715]
#define sipNameNr_isSubtreeBlocked 6732
#define sipName_isSubtreeBlocked &sipStrings_QtQuick[6732]
#define sipNameNr_prependChildNode 6749
#define sipName_prependChildNode &sipStrings_QtQuick[6749]
#define sipNameNr_DirtyNodeRemoved 6766
#define sipName_DirtyNodeRemoved &sipStrings_QtQuick[6766]
#define sipNameNr_GeometryNodeType 6783
#define sipName_GeometryNodeType &sipStrings_QtQuick[6783]
#define sipNameNr_SrcAlphaSaturate 6800
#define sipName_SrcAlphaSaturate &sipStrings_QtQuick[6800]
#define sipNameNr_OneMinusDstAlpha 6817
#define sipName_OneMinusDstAlpha &sipStrings_QtQuick[6817]
#define sipNameNr_OneMinusSrcAlpha 6834
#define sipName_OneMinusSrcAlpha &sipStrings_QtQuick[6834]
#define sipNameNr_OneMinusDstColor 6851
#define sipName_OneMinusDstColor &sipStrings_QtQuick[6851]
#define sipNameNr_OneMinusSrcColor 6868
#define sipName_OneMinusSrcColor &sipStrings_QtQuick[6868]
#define sipNameNr_MirrorVertically 5253
#define sipName_MirrorVertically &sipStrings_QtQuick[5253]
#define sipNameNr_UnsignedByteType 6885
#define sipName_UnsignedByteType &sipStrings_QtQuick[6885]
#define sipNameNr_UnknownAttribute 6902
#define sipName_UnknownAttribute &sipStrings_QtQuick[6902]
#define sipNameNr_indexDataPattern 6919
#define sipName_indexDataPattern &sipStrings_QtQuick[6919]
#define sipNameNr_projectionMatrix 6936
#define sipName_projectionMatrix &sipStrings_QtQuick[6936]
#define sipNameNr_ClearDepthBuffer 6953
#define sipName_ClearDepthBuffer &sipStrings_QtQuick[6953]
#define sipNameNr_ClearColorBuffer 6970
#define sipName_ClearColorBuffer &sipStrings_QtQuick[6970]
#define sipNameNr_QQuickCloseEvent 6987
#define sipName_QQuickCloseEvent &sipStrings_QtQuick[6987]
#define sipNameNr_NativeObjectType 1487
#define sipName_NativeObjectType &sipStrings_QtQuick[1487]
#define sipNameNr_resetOpenGLState 7004
#define sipName_resetOpenGLState &sipStrings_QtQuick[7004]
#define sipNameNr_renderTargetSize 7021
#define sipName_renderTargetSize &sipStrings_QtQuick[7021]
#define sipNameNr_mouseGrabberItem 7038
#define sipName_mouseGrabberItem &sipStrings_QtQuick[7038]
#define sipNameNr_fillColorChanged 7055
#define sipName_fillColorChanged &sipStrings_QtQuick[7055]
#define sipNameNr_setContentsScale 7072
#define sipName_setContentsScale &sipStrings_QtQuick[7072]
#define sipNameNr_performanceHints 7089
#define sipName_performanceHints &sipStrings_QtQuick[7089]
#define sipNameNr_PerformanceHints 831
#define sipName_PerformanceHints &sipStrings_QtQuick[831]
#define sipNameNr_activeFocusOnTab 7106
#define sipName_activeFocusOnTab &sipStrings_QtQuick[7106]
#define sipNameNr_touchUngrabEvent 7123
#define sipName_touchUngrabEvent &sipStrings_QtQuick[7123]
#define sipNameNr_mouseUngrabEvent 7140
#define sipName_mouseUngrabEvent &sipStrings_QtQuick[7140]
#define sipNameNr_inputMethodEvent 7157
#define sipName_inputMethodEvent &sipStrings_QtQuick[7157]
#define sipNameNr_inputMethodQuery 7174
#define sipName_inputMethodQuery &sipStrings_QtQuick[7174]
#define sipNameNr_forceActiveFocus 7191
#define sipName_forceActiveFocus &sipStrings_QtQuick[7191]
#define sipNameNr_mapRectFromScene 7208
#define sipName_mapRectFromScene &sipStrings_QtQuick[7208]
#define sipNameNr_setKeepTouchGrab 7225
#define sipName_setKeepTouchGrab &sipStrings_QtQuick[7225]
#define sipNameNr_setKeepMouseGrab 7242
#define sipName_setKeepMouseGrab &sipStrings_QtQuick[7242]
#define sipNameNr_setImplicitWidth 7259
#define sipName_setImplicitWidth &sipStrings_QtQuick[7259]
#define sipNameNr_ItemAcceptsDrops 7276
#define sipName_ItemAcceptsDrops &sipStrings_QtQuick[7276]
#define sipNameNr_ItemIsFocusScope 7293
#define sipName_ItemIsFocusScope &sipStrings_QtQuick[7293]
#define sipNameNr_QQuickItem__Flag 7310
#define sipName_QQuickItem__Flag &sipStrings_QtQuick[7310]
#define sipNameNr_textureByteCount 7327
#define sipName_textureByteCount &sipStrings_QtQuick[7327]
#define sipNameNr_mirrorVertically 7344
#define sipName_mirrorVertically &sipStrings_QtQuick[7344]
#define sipNameNr_releaseResources 7361
#define sipName_releaseResources &sipStrings_QtQuick[7361]
#define sipNameNr_devicePixelRatio 7378
#define sipName_devicePixelRatio &sipStrings_QtQuick[7378]
#define sipNameNr_disconnectNotify 7395
#define sipName_disconnectNotify &sipStrings_QtQuick[7395]
#define sipNameNr_anisotropyLevel 7412
#define sipName_anisotropyLevel &sipStrings_QtQuick[7412]
#define sipNameNr_AnisotropyLevel 1813
#define sipName_AnisotropyLevel &sipStrings_QtQuick[1813]
#define sipNameNr_OpaqueRendering 7428
#define sipName_OpaqueRendering &sipStrings_QtQuick[7428]
#define sipNameNr_PainterResource 7444
#define sipName_PainterResource &sipStrings_QtQuick[7444]
#define sipNameNr_previousSibling 7460
#define sipName_previousSibling &sipStrings_QtQuick[7460]
#define sipNameNr_appendChildNode 7476
#define sipName_appendChildNode &sipStrings_QtQuick[7476]
#define sipNameNr_removeChildNode 7492
#define sipName_removeChildNode &sipStrings_QtQuick[7492]
#define sipNameNr_OpacityNodeType 7508
#define sipName_OpacityNodeType &sipStrings_QtQuick[7508]
#define sipNameNr_RhiShaderWanted 7524
#define sipName_RhiShaderWanted &sipStrings_QtQuick[7524]
#define sipNameNr_QSGMaterialType 7540
#define sipName_QSGMaterialType &sipStrings_QtQuick[7540]
#define sipNameNr_modelViewMatrix 7556
#define sipName_modelViewMatrix &sipStrings_QtQuick[7556]
#define sipNameNr_rebuildGeometry 7572
#define sipName_rebuildGeometry &sipStrings_QtQuick[7572]
#define sipNameNr_mipmapFiltering 7588
#define sipName_mipmapFiltering &sipStrings_QtQuick[7588]
#define sipNameNr_QSGGeometryNode 7604
#define sipName_QSGGeometryNode &sipStrings_QtQuick[7604]
#define sipNameNr_UnsignedIntType 7620
#define sipName_UnsignedIntType &sipStrings_QtQuick[7620]
#define sipNameNr_DrawTriangleFan 7636
#define sipName_DrawTriangleFan &sipStrings_QtQuick[7636]
#define sipNameNr_indexDataAsUInt 7652
#define sipName_indexDataAsUInt &sipStrings_QtQuick[7652]
#define sipNameNr_TexturedPoint2D 1038
#define sipName_TexturedPoint2D &sipStrings_QtQuick[1038]
#define sipNameNr_GL_TRIANGLE_FAN 7668
#define sipName_GL_TRIANGLE_FAN &sipStrings_QtQuick[7668]
#define sipNameNr_setViewportRect 7684
#define sipName_setViewportRect &sipStrings_QtQuick[7684]
#define sipNameNr_QtTextRendering 7700
#define sipName_QtTextRendering &sipStrings_QtQuick[7700]
#define sipNameNr_createImageNode 7716
#define sipName_createImageNode &sipStrings_QtQuick[7716]
#define sipNameNr_sceneGraphError 7732
#define sipName_sceneGraphError &sipStrings_QtQuick[7732]
#define sipNameNr_SceneGraphError 1609
#define sipName_SceneGraphError &sipStrings_QtQuick[1609]
#define sipNameNr_beforeRendering 7748
#define sipName_beforeRendering &sipStrings_QtQuick[7748]
#define sipNameNr_activeFocusItem 7764
#define sipName_activeFocusItem &sipStrings_QtQuick[7764]
#define sipNameNr_TextureIsOpaque 7780
#define sipName_TextureIsOpaque &sipStrings_QtQuick[7780]
#define sipNameNr_renderRequested 7796
#define sipName_renderRequested &sipStrings_QtQuick[7796]
#define sipNameNr_renderWindowFor 7812
#define sipName_renderWindowFor &sipStrings_QtQuick[7812]
#define sipNameNr_setRenderTarget 7828
#define sipName_setRenderTarget &sipStrings_QtQuick[7828]
#define sipNameNr_setContentsSize 6327
#define sipName_setContentsSize &sipStrings_QtQuick[6327]
#define sipNameNr_FastFBOResizing 7844
#define sipName_FastFBOResizing &sipStrings_QtQuick[7844]
#define sipNameNr_containmentMask 7860
#define sipName_containmentMask &sipStrings_QtQuick[7860]
#define sipNameNr_hoverLeaveEvent 7876
#define sipName_hoverLeaveEvent &sipStrings_QtQuick[7876]
#define sipNameNr_hoverEnterEvent 7892
#define sipName_hoverEnterEvent &sipStrings_QtQuick[7892]
#define sipNameNr_mapRectFromItem 7908
#define sipName_mapRectFromItem &sipStrings_QtQuick[7908]
#define sipNameNr_grabTouchPoints 6435
#define sipName_grabTouchPoints &sipStrings_QtQuick[6435]
#define sipNameNr_scopedFocusItem 7924
#define sipName_scopedFocusItem &sipStrings_QtQuick[7924]
#define sipNameNr_setAntialiasing 6399
#define sipName_setAntialiasing &sipStrings_QtQuick[6399]
#define sipNameNr_transformOrigin 7940
#define sipName_transformOrigin &sipStrings_QtQuick[7940]
#define sipNameNr_TransformOrigin 1981
#define sipName_TransformOrigin &sipStrings_QtQuick[1981]
#define sipNameNr_ItemSceneChange 7956
#define sipName_ItemSceneChange &sipStrings_QtQuick[7956]
#define sipNameNr_ItemHasContents 7972
#define sipName_ItemHasContents &sipStrings_QtQuick[7972]
#define sipNameNr_textureProvider 7988
#define sipName_textureProvider &sipStrings_QtQuick[7988]
#define sipNameNr_updatePaintNode 8004
#define sipName_updatePaintNode &sipStrings_QtQuick[8004]
#define sipNameNr_mousePressEvent 8020
#define sipName_mousePressEvent &sipStrings_QtQuick[8020]
#define sipNameNr_keyReleaseEvent 8036
#define sipName_keyReleaseEvent &sipStrings_QtQuick[8036]
#define sipNameNr_PerformanceHint 902
#define sipName_PerformanceHint &sipStrings_QtQuick[902]
#define sipNameNr_geometryChanged 8052
#define sipName_geometryChanged &sipStrings_QtQuick[8052]
#define sipNameNr_hasAlphaChannel 8068
#define sipName_hasAlphaChannel &sipStrings_QtQuick[8068]
#define sipNameNr_textureChanged 8084
#define sipName_textureChanged &sipStrings_QtQuick[8084]
#define sipNameNr_AnisotropyNone 8099
#define sipName_AnisotropyNone &sipStrings_QtQuick[8099]
#define sipNameNr_isAtlasTexture 8114
#define sipName_isAtlasTexture &sipStrings_QtQuick[8114]
#define sipNameNr_stencilEnabled 8129
#define sipName_stencilEnabled &sipStrings_QtQuick[8129]
#define sipNameNr_scissorEnabled 8144
#define sipName_scissorEnabled &sipStrings_QtQuick[8144]
#define sipNameNr_RenderingFlags 1580
#define sipName_RenderingFlags &sipStrings_QtQuick[1580]
#define sipNameNr_ShaderByteCode 8159
#define sipName_ShaderByteCode &sipStrings_QtQuick[8159]
#define sipNameNr_DeviceResource 3222
#define sipName_DeviceResource &sipStrings_QtQuick[3222]
#define sipNameNr_QSGOpacityNode 8174
#define sipName_QSGOpacityNode &sipStrings_QtQuick[8174]
#define sipNameNr_opaqueMaterial 8189
#define sipName_opaqueMaterial &sipStrings_QtQuick[8189]
#define sipNameNr_DirtyNodeAdded 8204
#define sipName_DirtyNodeAdded &sipStrings_QtQuick[8204]
#define sipNameNr_QSGNode__Flags 8219
#define sipName_QSGNode__Flags &sipStrings_QtQuick[8219]
#define sipNameNr_fragmentShader 8234
#define sipName_fragmentShader &sipStrings_QtQuick[8234]
#define sipNameNr_attributeNames 8249
#define sipName_attributeNames &sipStrings_QtQuick[8249]
#define sipNameNr_combinedMatrix 8264
#define sipName_combinedMatrix &sipStrings_QtQuick[8264]
#define sipNameNr_isOpacityDirty 8279
#define sipName_isOpacityDirty &sipStrings_QtQuick[8279]
#define sipNameNr_setOwnsTexture 8294
#define sipName_setOwnsTexture &sipStrings_QtQuick[8294]
#define sipNameNr_ColorAttribute 8309
#define sipName_ColorAttribute &sipStrings_QtQuick[8309]
#define sipNameNr_attributeCount 8324
#define sipName_attributeCount &sipStrings_QtQuick[8324]
#define sipNameNr_setDrawingMode 8339
#define sipName_setDrawingMode &sipStrings_QtQuick[8339]
#define sipNameNr_DynamicPattern 8354
#define sipName_DynamicPattern &sipStrings_QtQuick[8354]
#define sipNameNr_ColoredPoint2D 1207
#define sipName_ColoredPoint2D &sipStrings_QtQuick[1207]
#define sipNameNr_textRenderType 8369
#define sipName_textRenderType &sipStrings_QtQuick[8369]
#define sipNameNr_TextRenderType 1786
#define sipName_TextRenderType &sipStrings_QtQuick[1786]
#define sipNameNr_AfterSwapStage 8384
#define sipName_AfterSwapStage &sipStrings_QtQuick[8384]
#define sipNameNr_afterAnimating 8399
#define sipName_afterAnimating &sipStrings_QtQuick[8399]
#define sipNameNr_afterRendering 8414
#define sipName_afterRendering &sipStrings_QtQuick[8414]
#define sipNameNr_renderTargetId 8429
#define sipName_renderTargetId &sipStrings_QtQuick[8429]
#define sipNameNr_setTextureSize 8444
#define sipName_setTextureSize &sipStrings_QtQuick[8444]
#define sipNameNr_opaquePainting 8459
#define sipName_opaquePainting &sipStrings_QtQuick[8459]
#define sipNameNr_dragLeaveEvent 8474
#define sipName_dragLeaveEvent &sipStrings_QtQuick[8474]
#define sipNameNr_dragEnterEvent 8489
#define sipName_dragEnterEvent &sipStrings_QtQuick[8489]
#define sipNameNr_hoverMoveEvent 8504
#define sipName_hoverMoveEvent &sipStrings_QtQuick[8504]
#define sipNameNr_mapRectToScene 8519
#define sipName_mapRectToScene &sipStrings_QtQuick[8519]
#define sipNameNr_hasActiveFocus 8534
#define sipName_hasActiveFocus &sipStrings_QtQuick[8534]
#define sipNameNr_implicitHeight 8549
#define sipName_implicitHeight &sipStrings_QtQuick[8549]
#define sipNameNr_baselineOffset 8564
#define sipName_baselineOffset &sipStrings_QtQuick[8564]
#define sipNameNr_ItemChangeData 2253
#define sipName_ItemChangeData &sipStrings_QtQuick[2253]
#define sipNameNr_textureFactory 8579
#define sipName_textureFactory &sipStrings_QtQuick[8579]
#define sipNameNr_requestTexture 8594
#define sipName_requestTexture &sipStrings_QtQuick[8594]
#define sipNameNr_createRenderer 8609
#define sipName_createRenderer &sipStrings_QtQuick[8609]
#define sipNameNr_mouseMoveEvent 8624
#define sipName_mouseMoveEvent &sipStrings_QtQuick[8624]
#define sipNameNr_MirroredRepeat 8639
#define sipName_MirroredRepeat &sipStrings_QtQuick[8639]
#define sipNameNr_updateTexture 8654
#define sipName_updateTexture &sipStrings_QtQuick[8654]
#define sipNameNr_nativeTexture 8668
#define sipName_nativeTexture &sipStrings_QtQuick[8668]
#define sipNameNr_NativeTexture 2307
#define sipName_NativeTexture &sipStrings_QtQuick[2307]
#define sipNameNr_comparisonKey 8682
#define sipName_comparisonKey &sipStrings_QtQuick[8682]
#define sipNameNr_Anisotropy16x 8696
#define sipName_Anisotropy16x &sipStrings_QtQuick[8696]
#define sipNameNr_changedStates 8710
#define sipName_changedStates &sipStrings_QtQuick[8710]
#define sipNameNr_RenderingFlag 1700
#define sipName_RenderingFlag &sipStrings_QtQuick[1700]
#define sipNameNr_ViewportState 8724
#define sipName_ViewportState &sipStrings_QtQuick[8724]
#define sipNameNr_QSGRenderNode 8738
#define sipName_QSGRenderNode &sipStrings_QtQuick[8738]
#define sipNameNr_isApiRhiBased 8752
#define sipName_isApiRhiBased &sipStrings_QtQuick[8752]
#define sipNameNr_Direct3D11Rhi 8766
#define sipName_Direct3D11Rhi &sipStrings_QtQuick[8766]
#define sipNameNr_isRectangular 8780
#define sipName_isRectangular &sipStrings_QtQuick[8780]
#define sipNameNr_DirtyMaterial 8794
#define sipName_DirtyMaterial &sipStrings_QtQuick[8794]
#define sipNameNr_DirtyGeometry 8808
#define sipName_DirtyGeometry &sipStrings_QtQuick[8808]
#define sipNameNr_DirtyStateBit 3246
#define sipName_DirtyStateBit &sipStrings_QtQuick[3246]
#define sipNameNr_UsePreprocess 8822
#define sipName_UsePreprocess &sipStrings_QtQuick[8822]
#define sipNameNr_OwnedByParent 8836
#define sipName_OwnedByParent &sipStrings_QtQuick[8836]
#define sipNameNr_QSGNode__Flag 8850
#define sipName_QSGNode__Flag &sipStrings_QtQuick[8850]
#define sipNameNr_BasicNodeType 8864
#define sipName_BasicNodeType &sipStrings_QtQuick[8864]
#define sipNameNr_ConstantAlpha 3699
#define sipName_ConstantAlpha &sipStrings_QtQuick[3699]
#define sipNameNr_ConstantColor 3721
#define sipName_ConstantColor &sipStrings_QtQuick[3721]
#define sipNameNr_isMatrixDirty 8878
#define sipName_isMatrixDirty &sipStrings_QtQuick[8878]
#define sipNameNr_setSourceRect 8892
#define sipName_setSourceRect &sipStrings_QtQuick[8892]
#define sipNameNr_DrawTriangles 8906
#define sipName_DrawTriangles &sipStrings_QtQuick[8906]
#define sipNameNr_DrawLineStrip 8920
#define sipName_DrawLineStrip &sipStrings_QtQuick[8920]
#define sipNameNr_StaticPattern 8934
#define sipName_StaticPattern &sipStrings_QtQuick[8934]
#define sipNameNr_StreamPattern 8948
#define sipName_StreamPattern &sipStrings_QtQuick[8948]
#define sipNameNr_attributeType 8962
#define sipName_attributeType &sipStrings_QtQuick[8962]
#define sipNameNr_GL_LINE_STRIP 8976
#define sipName_GL_LINE_STRIP &sipStrings_QtQuick[8976]
#define sipNameNr_setClearColor 8990
#define sipName_setClearColor &sipStrings_QtQuick[8990]
#define sipNameNr_setDeviceRect 9004
#define sipName_setDeviceRect &sipStrings_QtQuick[9004]
#define sipNameNr_openglContext 9018
#define sipName_openglContext &sipStrings_QtQuick[9018]
#define sipNameNr_setResizeMode 9032
#define sipName_setResizeMode &sipStrings_QtQuick[9032]
#define sipNameNr_prepareThread 9046
#define sipName_prepareThread &sipStrings_QtQuick[9046]
#define sipNameNr_contentsScale 9060
#define sipName_contentsScale &sipStrings_QtQuick[9060]
#define sipNameNr_windowChanged 9074
#define sipName_windowChanged &sipStrings_QtQuick[9074]
#define sipNameNr_dragMoveEvent 9088
#define sipName_dragMoveEvent &sipStrings_QtQuick[9088]
#define sipNameNr_transformNode 9102
#define sipName_transformNode &sipStrings_QtQuick[9102]
#define sipNameNr_mapRectToItem 9116
#define sipName_mapRectToItem &sipStrings_QtQuick[9116]
#define sipNameNr_keepTouchGrab 9130
#define sipName_keepTouchGrab &sipStrings_QtQuick[9130]
#define sipNameNr_keepMouseGrab 9144
#define sipName_keepMouseGrab &sipStrings_QtQuick[9144]
#define sipNameNr_implicitWidth 9158
#define sipName_implicitWidth &sipStrings_QtQuick[9158]
#define sipNameNr_setParentItem 9172
#define sipName_setParentItem &sipStrings_QtQuick[9172]
#define sipNameNr_requestPixmap 9186
#define sipName_requestPixmap &sipStrings_QtQuick[9186]
#define sipNameNr_createTexture 9200
#define sipName_createTexture &sipStrings_QtQuick[9200]
#define sipNameNr_statusChanged 9214
#define sipName_statusChanged &sipStrings_QtQuick[9214]
#define sipNameNr_keyPressEvent 9228
#define sipName_keyPressEvent &sipStrings_QtQuick[9228]
#define sipNameNr_focusOutEvent 9242
#define sipName_focusOutEvent &sipStrings_QtQuick[9242]
#define sipNameNr_mapFromGlobal 9256
#define sipName_mapFromGlobal &sipStrings_QtQuick[9256]
#define sipNameNr_AttributeType 2092
#define sipName_AttributeType &sipStrings_QtQuick[2092]
#define sipNameNr_connectNotify 7398
#define sipName_connectNotify &sipStrings_QtQuick[7398]
#define sipNameNr_PyQt5_QtQuick 9270
#define sipName_PyQt5_QtQuick &sipStrings_QtQuick[9270]
#define sipNameNr_Anisotropy8x 9284
#define sipName_Anisotropy8x &sipStrings_QtQuick[9284]
#define sipNameNr_Anisotropy4x 9297
#define sipName_Anisotropy4x &sipStrings_QtQuick[9297]
#define sipNameNr_Anisotropy2x 9310
#define sipName_Anisotropy2x &sipStrings_QtQuick[9310]
#define sipNameNr_stencilValue 9323
#define sipName_stencilValue &sipStrings_QtQuick[9323]
#define sipNameNr_ScissorState 9336
#define sipName_ScissorState &sipStrings_QtQuick[9336]
#define sipNameNr_StencilState 9349
#define sipName_StencilState &sipStrings_QtQuick[9349]
#define sipNameNr_childAtIndex 9362
#define sipName_childAtIndex &sipStrings_QtQuick[9362]
#define sipNameNr_OwnsMaterial 9375
#define sipName_OwnsMaterial &sipStrings_QtQuick[9375]
#define sipNameNr_OwnsGeometry 9388
#define sipName_OwnsGeometry &sipStrings_QtQuick[9388]
#define sipNameNr_ClipNodeType 9401
#define sipName_ClipNodeType &sipStrings_QtQuick[9401]
#define sipNameNr_vertexShader 9414
#define sipName_vertexShader &sipStrings_QtQuick[9414]
#define sipNameNr_setFiltering 9427
#define sipName_setFiltering &sipStrings_QtQuick[9427]
#define sipNameNr_QSGImageNode 9440
#define sipName_QSGImageNode &sipStrings_QtQuick[9440]
#define sipNameNr_DrawLineLoop 9453
#define sipName_DrawLineLoop &sipStrings_QtQuick[9453]
#define sipNameNr_sizeOfVertex 9466
#define sipName_sizeOfVertex &sipStrings_QtQuick[9466]
#define sipNameNr_AttributeSet 2438
#define sipName_AttributeSet &sipStrings_QtQuick[2438]
#define sipNameNr_GL_TRIANGLES 9479
#define sipName_GL_TRIANGLES &sipStrings_QtQuick[9479]
#define sipNameNr_GL_LINE_LOOP 9492
#define sipName_GL_LINE_LOOP &sipStrings_QtQuick[9492]
#define sipNameNr_createShader 9505
#define sipName_createShader &sipStrings_QtQuick[9505]
#define sipNameNr_setClearMode 9518
#define sipName_setClearMode &sipStrings_QtQuick[9518]
#define sipNameNr_viewportRect 9531
#define sipName_viewportRect &sipStrings_QtQuick[9531]
#define sipNameNr_ClearModeBit 1075
#define sipName_ClearModeBit &sipStrings_QtQuick[1075]
#define sipNameNr_colorChanged 9544
#define sipName_colorChanged &sipStrings_QtQuick[9544]
#define sipNameNr_QQuickWindow 9557
#define sipName_QQuickWindow &sipStrings_QtQuick[9557]
#define sipNameNr_textDocument 9570
#define sipName_textDocument &sipStrings_QtQuick[9570]
#define sipNameNr_sceneChanged 9583
#define sipName_sceneChanged &sipStrings_QtQuick[9583]
#define sipNameNr_renderWindow 9596
#define sipName_renderWindow &sipStrings_QtQuick[9596]
#define sipNameNr_renderTarget 9609
#define sipName_renderTarget &sipStrings_QtQuick[9609]
#define sipNameNr_setFillColor 9622
#define sipName_setFillColor &sipStrings_QtQuick[9622]
#define sipNameNr_contentsSize 9635
#define sipName_contentsSize &sipStrings_QtQuick[9635]
#define sipNameNr_RenderTarget 1273
#define sipName_RenderTarget &sipStrings_QtQuick[1273]
#define sipNameNr_updatePolish 9648
#define sipName_updatePolish &sipStrings_QtQuick[9648]
#define sipNameNr_mapFromScene 9661
#define sipName_mapFromScene &sipStrings_QtQuick[9661]
#define sipNameNr_isFocusScope 9674
#define sipName_isFocusScope &sipStrings_QtQuick[9674]
#define sipNameNr_antialiasing 9687
#define sipName_antialiasing &sipStrings_QtQuick[9687]
#define sipNameNr_childrenRect 9700
#define sipName_childrenRect &sipStrings_QtQuick[9700]
#define sipNameNr_requestImage 9713
#define sipName_requestImage &sipStrings_QtQuick[9713]
#define sipNameNr_focusInEvent 9726
#define sipName_focusInEvent &sipStrings_QtQuick[9726]
#define sipNameNr_isAncestorOf 9739
#define sipName_isAncestorOf &sipStrings_QtQuick[9739]
#define sipNameNr_setLineWidth 9752
#define sipName_setLineWidth &sipStrings_QtQuick[9752]
#define sipNameNr_DirtyOpacity 9765
#define sipName_DirtyOpacity &sipStrings_QtQuick[9765]
#define sipNameNr_frameSwapped 9778
#define sipName_frameSwapped &sipStrings_QtQuick[9778]
#define sipNameNr_scissorRect 9791
#define sipName_scissorRect &sipStrings_QtQuick[9791]
#define sipNameNr_getResource 9803
#define sipName_getResource &sipStrings_QtQuick[9803]
#define sipNameNr_graphicsApi 9815
#define sipName_graphicsApi &sipStrings_QtQuick[9815]
#define sipNameNr_RhiResource 9827
#define sipName_RhiResource &sipStrings_QtQuick[9827]
#define sipNameNr_GraphicsApi 940
#define sipName_GraphicsApi &sipStrings_QtQuick[940]
#define sipNameNr_QSGClipNode 9839
#define sipName_QSGClipNode &sipStrings_QtQuick[9839]
#define sipNameNr_setMaterial 9851
#define sipName_setMaterial &sipStrings_QtQuick[9851]
#define sipNameNr_nextSibling 9863
#define sipName_nextSibling &sipStrings_QtQuick[9863]
#define sipNameNr_BlendFactor 109
#define sipName_BlendFactor &sipStrings_QtQuick[109]
#define sipNameNr_uniformData 9875
#define sipName_uniformData &sipStrings_QtQuick[9875]
#define sipNameNr_dirtyStates 9887
#define sipName_dirtyStates &sipStrings_QtQuick[9887]
#define sipNameNr_DirtyStates 595
#define sipName_DirtyStates &sipStrings_QtQuick[595]
#define sipNameNr_DirtyMatrix 9899
#define sipName_DirtyMatrix &sipStrings_QtQuick[9899]
#define sipNameNr_RenderState 974
#define sipName_RenderState &sipStrings_QtQuick[974]
#define sipNameNr_ownsTexture 9911
#define sipName_ownsTexture &sipStrings_QtQuick[9911]
#define sipNameNr_NoTransform 9923
#define sipName_NoTransform &sipStrings_QtQuick[9923]
#define sipNameNr_DrawingMode 2721
#define sipName_DrawingMode &sipStrings_QtQuick[2721]
#define sipNameNr_sizeOfIndex 9935
#define sipName_sizeOfIndex &sipStrings_QtQuick[9935]
#define sipNameNr_drawingMode 9947
#define sipName_drawingMode &sipStrings_QtQuick[9947]
#define sipNameNr_vertexCount 9959
#define sipName_vertexCount &sipStrings_QtQuick[9959]
#define sipNameNr_DataPattern 2746
#define sipName_DataPattern &sipStrings_QtQuick[2746]
#define sipNameNr_QSGGeometry 9971
#define sipName_QSGGeometry &sipStrings_QtQuick[9971]
#define sipNameNr_QSGMaterial 9983
#define sipName_QSGMaterial &sipStrings_QtQuick[9983]
#define sipNameNr_renderScene 9995
#define sipName_renderScene &sipStrings_QtQuick[9995]
#define sipNameNr_RenderStage 2543
#define sipName_RenderStage &sipStrings_QtQuick[2543]
#define sipNameNr_contentItem 10007
#define sipName_contentItem &sipStrings_QtQuick[10007]
#define sipNameNr_initialSize 10019
#define sipName_initialSize &sipStrings_QtQuick[10019]
#define sipNameNr_polishItems 10031
#define sipName_polishItems &sipStrings_QtQuick[10031]
#define sipNameNr_grabToImage 10043
#define sipName_grabToImage &sipStrings_QtQuick[10043]
#define sipNameNr_heightValid 10055
#define sipName_heightValid &sipStrings_QtQuick[10055]
#define sipNameNr_mapFromItem 10067
#define sipName_mapFromItem &sipStrings_QtQuick[10067]
#define sipNameNr_ungrabMouse 10079
#define sipName_ungrabMouse &sipStrings_QtQuick[10079]
#define sipNameNr_setRotation 10091
#define sipName_setRotation &sipStrings_QtQuick[10091]
#define sipNameNr_resetHeight 10103
#define sipName_resetHeight &sipStrings_QtQuick[10103]
#define sipNameNr_stackBefore 10115
#define sipName_stackBefore &sipStrings_QtQuick[10115]
#define sipNameNr_BottomRight 10127
#define sipName_BottomRight &sipStrings_QtQuick[10127]
#define sipNameNr_synchronize 10139
#define sipName_synchronize &sipStrings_QtQuick[10139]
#define sipNameNr_rootContext 10151
#define sipName_rootContext &sipStrings_QtQuick[10151]
#define sipNameNr_tabletEvent 10163
#define sipName_tabletEvent &sipStrings_QtQuick[10163]
#define sipNameNr_unsetCursor 10175
#define sipName_unsetCursor &sipStrings_QtQuick[10175]
#define sipNameNr_mapToGlobal 10187
#define sipName_mapToGlobal &sipStrings_QtQuick[10187]
#define sipNameNr_setGeometry 10199
#define sipName_setGeometry &sipStrings_QtQuick[10199]
#define sipNameNr_exposeEvent 10211
#define sipName_exposeEvent &sipStrings_QtQuick[10211]
#define sipNameNr_resizeEvent 10223
#define sipName_resizeEvent &sipStrings_QtQuick[10223]
#define sipNameNr_textureSize 10235
#define sipName_textureSize &sipStrings_QtQuick[10235]
#define sipNameNr_ClampToEdge 10247
#define sipName_ClampToEdge &sipStrings_QtQuick[10247]
#define sipNameNr_surfaceType 10259
#define sipName_surfaceType &sipStrings_QtQuick[10259]
#define sipNameNr_determinant 10271
#define sipName_determinant &sipStrings_QtQuick[10271]
#define sipNameNr_setClipRect 10283
#define sipName_setClipRect &sipStrings_QtQuick[10283]
#define sipNameNr_focusObject 10295
#define sipName_focusObject &sipStrings_QtQuick[10295]
#define sipNameNr_customEvent 10307
#define sipName_customEvent &sipStrings_QtQuick[10307]
#define sipNameNr_eventFilter 10319
#define sipName_eventFilter &sipStrings_QtQuick[10319]
#define sipNameNr_errorString 10331
#define sipName_errorString &sipStrings_QtQuick[10331]
#define sipNameNr_updateState 10343
#define sipName_updateState &sipStrings_QtQuick[10343]
#define sipNameNr_hasMipmaps 10355
#define sipName_hasMipmaps &sipStrings_QtQuick[10355]
#define sipNameNr_QSGTexture 10366
#define sipName_QSGTexture &sipStrings_QtQuick[10366]
#define sipNameNr_BlendState 10377
#define sipName_BlendState &sipStrings_QtQuick[10377]
#define sipNameNr_ColorState 10388
#define sipName_ColorState &sipStrings_QtQuick[10388]
#define sipNameNr_DepthState 10399
#define sipName_DepthState &sipStrings_QtQuick[10399]
#define sipNameNr_Direct3D12 10410
#define sipName_Direct3D12 &sipStrings_QtQuick[10410]
#define sipNameNr_preprocess 10421
#define sipName_preprocess &sipStrings_QtQuick[10421]
#define sipNameNr_firstChild 10432
#define sipName_firstChild &sipStrings_QtQuick[10432]
#define sipNameNr_childCount 10443
#define sipName_childCount &sipStrings_QtQuick[10443]
#define sipNameNr_deactivate 10454
#define sipName_deactivate &sipStrings_QtQuick[10454]
#define sipNameNr_DirtyState 639
#define sipName_DirtyState &sipStrings_QtQuick[639]
#define sipNameNr_DoubleType 10465
#define sipName_DoubleType &sipStrings_QtQuick[10465]
#define sipNameNr_Bytes4Type 10476
#define sipName_Bytes4Type &sipStrings_QtQuick[10476]
#define sipNameNr_Bytes3Type 10487
#define sipName_Bytes3Type &sipStrings_QtQuick[10487]
#define sipNameNr_Bytes2Type 10498
#define sipName_Bytes2Type &sipStrings_QtQuick[10498]
#define sipNameNr_DrawPoints 10509
#define sipName_DrawPoints &sipStrings_QtQuick[10509]
#define sipNameNr_vertexData 10520
#define sipName_vertexData &sipStrings_QtQuick[10520]
#define sipNameNr_indexCount 10531
#define sipName_indexCount &sipStrings_QtQuick[10531]
#define sipNameNr_isPosition 10542
#define sipName_isPosition &sipStrings_QtQuick[10542]
#define sipNameNr_clearColor 10553
#define sipName_clearColor &sipStrings_QtQuick[10553]
#define sipNameNr_deviceRect 10564
#define sipName_deviceRect &sipStrings_QtQuick[10564]
#define sipNameNr_resizeMode 10575
#define sipName_resizeMode &sipStrings_QtQuick[10575]
#define sipNameNr_ResizeMode 3387
#define sipName_ResizeMode &sipStrings_QtQuick[3387]
#define sipNameNr_rootObject 10586
#define sipName_rootObject &sipStrings_QtQuick[10586]
#define sipNameNr_QQuickView 10597
#define sipName_QQuickView &sipStrings_QtQuick[10597]
#define sipNameNr_saveToFile 10608
#define sipName_saveToFile &sipStrings_QtQuick[10608]
#define sipNameNr_targetSize 10619
#define sipName_targetSize &sipStrings_QtQuick[10619]
#define sipNameNr_widthValid 10630
#define sipName_widthValid &sipStrings_QtQuick[10630]
#define sipNameNr_itemChange 10641
#define sipName_itemChange &sipStrings_QtQuick[10641]
#define sipNameNr_mapToScene 10652
#define sipName_mapToScene &sipStrings_QtQuick[10652]
#define sipNameNr_resetWidth 10663
#define sipName_resetWidth &sipStrings_QtQuick[10663]
#define sipNameNr_childItems 10674
#define sipName_childItems &sipStrings_QtQuick[10674]
#define sipNameNr_stackAfter 10685
#define sipName_stackAfter &sipStrings_QtQuick[10685]
#define sipNameNr_parentItem 10696
#define sipName_parentItem &sipStrings_QtQuick[10696]
#define sipNameNr_BottomLeft 10707
#define sipName_BottomLeft &sipStrings_QtQuick[10707]
#define sipNameNr_ItemChange 3479
#define sipName_ItemChange &sipStrings_QtQuick[3479]
#define sipNameNr_QQuickItem 10718
#define sipName_QQuickItem &sipStrings_QtQuick[10718]
#define sipNameNr_classBegin 10729
#define sipName_classBegin &sipStrings_QtQuick[10729]
#define sipNameNr_StateFlags 2336
#define sipName_StateFlags &sipStrings_QtQuick[2336]
#define sipNameNr_touchEvent 10740
#define sipName_touchEvent &sipStrings_QtQuick[10740]
#define sipNameNr_wheelEvent 10751
#define sipName_wheelEvent &sipStrings_QtQuick[10751]
#define sipNameNr_grabWindow 10762
#define sipName_grabWindow &sipStrings_QtQuick[10762]
#define sipNameNr_clipRegion 10773
#define sipName_clipRegion &sipStrings_QtQuick[10773]
#define sipNameNr_setOpacity 10784
#define sipName_setOpacity &sipStrings_QtQuick[10784]
#define sipNameNr_shaderType 10795
#define sipName_shaderType &sipStrings_QtQuick[10795]
#define sipNameNr_ShaderType 1178
#define sipName_ShaderType &sipStrings_QtQuick[1178]
#define sipNameNr_sourceRect 10806
#define sipName_sourceRect &sipStrings_QtQuick[10806]
#define sipNameNr_setVisible 10817
#define sipName_setVisible &sipStrings_QtQuick[10817]
#define sipNameNr_initialize 10828
#define sipName_initialize &sipStrings_QtQuick[10828]
#define sipNameNr_setTexture 10839
#define sipName_setTexture &sipStrings_QtQuick[10839]
#define sipNameNr_attributes 10850
#define sipName_attributes &sipStrings_QtQuick[10850]
#define sipNameNr_childEvent 10861
#define sipName_childEvent &sipStrings_QtQuick[10861]
#define sipNameNr_timerEvent 10872
#define sipName_timerEvent &sipStrings_QtQuick[10872]
#define sipNameNr_setEnabled 10883
#define sipName_setEnabled &sipStrings_QtQuick[10883]
#define sipNameNr_invalidate 10894
#define sipName_invalidate &sipStrings_QtQuick[10894]
#define sipNameNr___invert__ 10905
#define sipName___invert__ &sipStrings_QtQuick[10905]
#define sipNameNr_Filtering 3593
#define sipName_Filtering &sipStrings_QtQuick[3593]
#define sipNameNr_CullState 10916
#define sipName_CullState &sipStrings_QtQuick[10916]
#define sipNameNr_RhiShader 4135
#define sipName_RhiShader &sipStrings_QtQuick[4135]
#define sipNameNr_VulkanRhi 10926
#define sipName_VulkanRhi &sipStrings_QtQuick[10926]
#define sipNameNr_OpenGLRhi 10936
#define sipName_OpenGLRhi &sipStrings_QtQuick[10936]
#define sipNameNr_markDirty 10946
#define sipName_markDirty &sipStrings_QtQuick[10946]
#define sipNameNr_lastChild 10956
#define sipName_lastChild &sipStrings_QtQuick[10956]
#define sipNameNr_CullFront 10966
#define sipName_CullFront &sipStrings_QtQuick[10966]
#define sipNameNr_ColorMask 166
#define sipName_ColorMask &sipStrings_QtQuick[166]
#define sipNameNr_Src1Alpha 5973
#define sipName_Src1Alpha &sipStrings_QtQuick[5973]
#define sipNameNr_Src1Color 5991
#define sipName_Src1Color &sipStrings_QtQuick[5991]
#define sipNameNr_filtering 10976
#define sipName_filtering &sipStrings_QtQuick[10976]
#define sipNameNr_FloatType 10986
#define sipName_FloatType &sipStrings_QtQuick[10986]
#define sipNameNr_ShortType 6081
#define sipName_ShortType &sipStrings_QtQuick[6081]
#define sipNameNr_DrawLines 10996
#define sipName_DrawLines &sipStrings_QtQuick[10996]
#define sipNameNr_indexData 11006
#define sipName_indexData &sipStrings_QtQuick[11006]
#define sipNameNr_indexType 11016
#define sipName_indexType &sipStrings_QtQuick[11016]
#define sipNameNr_GL_POINTS 11026
#define sipName_GL_POINTS &sipStrings_QtQuick[11026]
#define sipNameNr_QSGEngine 11036
#define sipName_QSGEngine &sipStrings_QtQuick[11036]
#define sipNameNr_clearMode 11046
#define sipName_clearMode &sipStrings_QtQuick[11046]
#define sipNameNr_ClearMode 1463
#define sipName_ClearMode &sipStrings_QtQuick[1463]
#define sipNameNr_setSource 11056
#define sipName_setSource &sipStrings_QtQuick[11056]
#define sipNameNr_fillColor 11066
#define sipName_fillColor &sipStrings_QtQuick[11066]
#define sipNameNr_dropEvent 11076
#define sipName_dropEvent &sipStrings_QtQuick[11076]
#define sipNameNr_mapToItem 11086
#define sipName_mapToItem &sipStrings_QtQuick[11086]
#define sipNameNr_grabMouse 10081
#define sipName_grabMouse &sipStrings_QtQuick[10081]
#define sipNameNr_setSmooth 11096
#define sipName_setSmooth &sipStrings_QtQuick[11096]
#define sipNameNr_boolValue 11106
#define sipName_boolValue &sipStrings_QtQuick[11106]
#define sipNameNr_realValue 11116
#define sipName_realValue &sipStrings_QtQuick[11116]
#define sipNameNr_imageType 11126
#define sipName_imageType &sipStrings_QtQuick[11126]
#define sipNameNr_StateFlag 2698
#define sipName_StateFlag &sipStrings_QtQuick[2698]
#define sipNameNr_hideEvent 11136
#define sipName_hideEvent &sipStrings_QtQuick[11136]
#define sipNameNr_showEvent 11146
#define sipName_showEvent &sipStrings_QtQuick[11146]
#define sipNameNr_moveEvent 11156
#define sipName_moveEvent &sipStrings_QtQuick[11156]
#define sipNameNr_setCursor 10177
#define sipName_setCursor &sipStrings_QtQuick[10177]
#define sipNameNr_setMatrix 11166
#define sipName_setMatrix &sipStrings_QtQuick[11166]
#define sipNameNr_textureId 11176
#define sipName_textureId &sipStrings_QtQuick[11176]
#define sipNameNr_tupleSize 11186
#define sipName_tupleSize &sipStrings_QtQuick[11186]
#define sipNameNr_setMipmap 11196
#define sipName_setMipmap &sipStrings_QtQuick[11196]
#define sipNameNr_isVisible 11206
#define sipName_isVisible &sipStrings_QtQuick[11206]
#define sipNameNr_lineWidth 11216
#define sipName_lineWidth &sipStrings_QtQuick[11216]
#define sipNameNr_Attribute 3273
#define sipName_Attribute &sipStrings_QtQuick[3273]
#define sipNameNr_setHeight 10105
#define sipName_setHeight &sipStrings_QtQuick[10105]
#define sipNameNr_isEnabled 11226
#define sipName_isEnabled &sipStrings_QtQuick[11226]
#define sipNameNr_sendEvent 11236
#define sipName_sendEvent &sipStrings_QtQuick[11236]
#define sipNameNr___index__ 11246
#define sipName___index__ &sipStrings_QtQuick[11246]
#define sipNameNr_clipList 11256
#define sipName_clipList &sipStrings_QtQuick[11256]
#define sipNameNr_Resource 1340
#define sipName_Resource &sipStrings_QtQuick[1340]
#define sipNameNr_MetalRhi 11265
#define sipName_MetalRhi &sipStrings_QtQuick[11265]
#define sipNameNr_Software 11274
#define sipName_Software &sipStrings_QtQuick[11274]
#define sipNameNr_material 11283
#define sipName_material &sipStrings_QtQuick[11283]
#define sipNameNr_NodeType 5920
#define sipName_NodeType &sipStrings_QtQuick[5920]
#define sipNameNr_CullBack 11292
#define sipName_CullBack &sipStrings_QtQuick[11292]
#define sipNameNr_CullNone 11301
#define sipName_CullNone &sipStrings_QtQuick[11301]
#define sipNameNr_CullMode 329
#define sipName_CullMode &sipStrings_QtQuick[329]
#define sipNameNr_DstAlpha 6825
#define sipName_DstAlpha &sipStrings_QtQuick[6825]
#define sipNameNr_SrcAlpha 6842
#define sipName_SrcAlpha &sipStrings_QtQuick[6842]
#define sipNameNr_DstColor 6859
#define sipName_DstColor &sipStrings_QtQuick[6859]
#define sipNameNr_SrcColor 6876
#define sipName_SrcColor &sipStrings_QtQuick[6876]
#define sipNameNr_Blending 11310
#define sipName_Blending &sipStrings_QtQuick[11310]
#define sipNameNr_activate 10456
#define sipName_activate &sipStrings_QtQuick[10456]
#define sipNameNr_DirtyAll 11319
#define sipName_DirtyAll &sipStrings_QtQuick[11319]
#define sipNameNr_ByteType 6893
#define sipName_ByteType &sipStrings_QtQuick[6893]
#define sipNameNr_GL_LINES 11328
#define sipName_GL_LINES &sipStrings_QtQuick[11328]
#define sipNameNr_GL_FLOAT 11337
#define sipName_GL_FLOAT &sipStrings_QtQuick[11337]
#define sipNameNr_setFocus 11346
#define sipName_setFocus &sipStrings_QtQuick[11346]
#define sipNameNr_hasFocus 11355
#define sipName_hasFocus &sipStrings_QtQuick[11355]
#define sipNameNr_setScale 11364
#define sipName_setScale &sipStrings_QtQuick[11364]
#define sipNameNr_setState 11373
#define sipName_setState &sipStrings_QtQuick[11373]
#define sipNameNr_TopRight 11382
#define sipName_TopRight &sipStrings_QtQuick[11382]
#define sipNameNr_Renderer 1147
#define sipName_Renderer &sipStrings_QtQuick[1147]
#define sipNameNr_geometry 11391
#define sipName_geometry &sipStrings_QtQuick[11391]
#define sipNameNr_WrapMode 3572
#define sipName_WrapMode &sipStrings_QtQuick[3572]
#define sipNameNr_allocate 11400
#define sipName_allocate &sipStrings_QtQuick[11400]
#define sipNameNr_clipRect 11409
#define sipName_clipRect &sipStrings_QtQuick[11409]
#define sipNameNr_rotation 11418
#define sipName_rotation &sipStrings_QtQuick[11418]
#define sipNameNr_setColor 11427
#define sipName_setColor &sipStrings_QtQuick[11427]
#define sipNameNr_position 11436
#define sipName_position &sipStrings_QtQuick[11436]
#define sipNameNr_setWidth 10665
#define sipName_setWidth &sipStrings_QtQuick[10665]
#define sipNameNr_setFlags 11445
#define sipName_setFlags &sipStrings_QtQuick[11445]
#define sipNameNr_contains 11454
#define sipName_contains &sipStrings_QtQuick[11454]
#define sipNameNr_finished 11463
#define sipName_finished &sipStrings_QtQuick[11463]
#define sipNameNr___hash__ 11472
#define sipName___hash__ &sipStrings_QtQuick[11472]
#define sipNameNr___bool__ 11481
#define sipName___bool__ &sipStrings_QtQuick[11481]
#define sipNameNr___ixor__ 11490
#define sipName___ixor__ &sipStrings_QtQuick[11490]
#define sipNameNr___iand__ 11499
#define sipName___iand__ &sipStrings_QtQuick[11499]
#define sipNameNr_NullRhi 11508
#define sipName_NullRhi &sipStrings_QtQuick[11508]
#define sipNameNr_QSGNode 11516
#define sipName_QSGNode &sipStrings_QtQuick[11516]
#define sipNameNr_compile 11524
#define sipName_compile &sipStrings_QtQuick[11524]
#define sipNameNr_IntType 7628
#define sipName_IntType &sipStrings_QtQuick[7628]
#define sipNameNr_Point2D 1046
#define sipName_Point2D &sipStrings_QtQuick[1046]
#define sipNameNr_GL_BYTE 11532
#define sipName_GL_BYTE &sipStrings_QtQuick[11532]
#define sipNameNr_NoStage 11540
#define sipName_NoStage &sipStrings_QtQuick[11540]
#define sipNameNr_closing 11548
#define sipName_closing &sipStrings_QtQuick[11548]
#define sipNameNr_forward 11556
#define sipName_forward &sipStrings_QtQuick[11556]
#define sipNameNr_childAt 11564
#define sipName_childAt &sipStrings_QtQuick[11564]
#define sipNameNr_setClip 11572
#define sipName_setClip &sipStrings_QtQuick[11572]
#define sipNameNr_TopLeft 11580
#define sipName_TopLeft &sipStrings_QtQuick[11580]
#define sipNameNr_Loading 11588
#define sipName_Loading &sipStrings_QtQuick[11588]
#define sipNameNr_opacity 11596
#define sipName_opacity &sipStrings_QtQuick[11596]
#define sipNameNr_Nearest 11604
#define sipName_Nearest &sipStrings_QtQuick[11604]
#define sipNameNr_setFlag 11612
#define sipName_setFlag &sipStrings_QtQuick[11612]
#define sipNameNr_queries 11620
#define sipName_queries &sipStrings_QtQuick[11620]
#define sipNameNr_texture 11628
#define sipName_texture &sipStrings_QtQuick[11628]
#define sipNameNr_setRect 11636
#define sipName_setRect &sipStrings_QtQuick[11636]
#define sipNameNr_program 11644
#define sipName_program &sipStrings_QtQuick[11644]
#define sipNameNr_Unknown 11652
#define sipName_Unknown &sipStrings_QtQuick[11652]
#define sipNameNr_enabled 11660
#define sipName_enabled &sipStrings_QtQuick[11660]
#define sipNameNr_context 11668
#define sipName_context &sipStrings_QtQuick[11668]
#define sipNameNr_compare 11676
#define sipName_compare &sipStrings_QtQuick[11676]
#define sipNameNr___len__ 11684
#define sipName___len__ &sipStrings_QtQuick[11684]
#define sipNameNr_options 11692
#define sipName_options &sipStrings_QtQuick[11692]
#define sipNameNr___xor__ 11700
#define sipName___xor__ &sipStrings_QtQuick[11700]
#define sipNameNr___ior__ 11708
#define sipName___ior__ &sipStrings_QtQuick[11708]
#define sipNameNr___and__ 11716
#define sipName___and__ &sipStrings_QtQuick[11716]
#define sipNameNr___int__ 11724
#define sipName___int__ &sipStrings_QtQuick[11724]
#define sipNameNr_GL_INT 11732
#define sipName_GL_INT &sipStrings_QtQuick[11732]
#define sipNameNr_polish 11739
#define sipName_polish &sipStrings_QtQuick[11739]
#define sipNameNr_smooth 11746
#define sipName_smooth &sipStrings_QtQuick[11746]
#define sipNameNr_Bottom 11753
#define sipName_Bottom &sipStrings_QtQuick[11753]
#define sipNameNr_Center 11760
#define sipName_Center &sipStrings_QtQuick[11760]
#define sipNameNr_render 11767
#define sipName_render &sipStrings_QtQuick[11767]
#define sipNameNr_errors 11774
#define sipName_errors &sipStrings_QtQuick[11774]
#define sipNameNr_layout 11781
#define sipName_layout &sipStrings_QtQuick[11781]
#define sipNameNr_OpenVG 11788
#define sipName_OpenVG &sipStrings_QtQuick[11788]
#define sipNameNr_OpenGL 11795
#define sipName_OpenGL &sipStrings_QtQuick[11795]
#define sipNameNr_Repeat 8647
#define sipName_Repeat &sipStrings_QtQuick[8647]
#define sipNameNr_stride 11802
#define sipName_stride &sipStrings_QtQuick[11802]
#define sipNameNr_mipmap 11809
#define sipName_mipmap &sipStrings_QtQuick[11809]
#define sipNameNr_engine 11816
#define sipName_engine &sipStrings_QtQuick[11816]
#define sipNameNr_source 1342
#define sipName_source &sipStrings_QtQuick[1342]
#define sipNameNr_matrix 11823
#define sipName_matrix &sipStrings_QtQuick[11823]
#define sipNameNr_window 11830
#define sipName_window &sipStrings_QtQuick[11830]
#define sipNameNr_update 11837
#define sipName_update &sipStrings_QtQuick[11837]
#define sipNameNr_cursor 11844
#define sipName_cursor &sipStrings_QtQuick[11844]
#define sipNameNr_cancel 11851
#define sipName_cancel &sipStrings_QtQuick[11851]
#define sipNameNr_create 11858
#define sipName_create &sipStrings_QtQuick[11858]
#define sipNameNr_height 11865
#define sipName_height &sipStrings_QtQuick[11865]
#define sipNameNr_offset 11872
#define sipName_offset &sipStrings_QtQuick[11872]
#define sipNameNr_Linear 11879
#define sipName_Linear &sipStrings_QtQuick[11879]
#define sipNameNr_status 11886
#define sipName_status &sipStrings_QtQuick[11886]
#define sipNameNr_Status 5719
#define sipName_Status &sipStrings_QtQuick[5719]
#define sipNameNr_format 11893
#define sipName_format &sipStrings_QtQuick[11893]
#define sipNameNr_object 11900
#define sipName_object &sipStrings_QtQuick[11900]
#define sipNameNr_parent 11907
#define sipName_parent &sipStrings_QtQuick[11907]
#define sipNameNr___ne__ 11914
#define sipName___ne__ &sipStrings_QtQuick[11914]
#define sipNameNr___eq__ 11921
#define sipName___eq__ &sipStrings_QtQuick[11921]
#define sipNameNr___or__ 11928
#define sipName___or__ &sipStrings_QtQuick[11928]
#define sipNameNr_force 11935
#define sipName_force &sipStrings_QtQuick[11935]
#define sipNameNr_fboId 11941
#define sipName_fboId &sipStrings_QtQuick[11941]
#define sipNameNr_ready 11947
#define sipName_ready &sipStrings_QtQuick[11947]
#define sipNameNr_Ready 11953
#define sipName_Ready &sipStrings_QtQuick[11953]
#define sipNameNr_Right 10133
#define sipName_Right &sipStrings_QtQuick[10133]
#define sipNameNr_paint 11959
#define sipName_paint &sipStrings_QtQuick[11959]
#define sipNameNr_Image 3346
#define sipName_Image &sipStrings_QtQuick[3346]
#define sipNameNr_scale 11965
#define sipName_scale &sipStrings_QtQuick[11965]
#define sipNameNr_color 11971
#define sipName_color &sipStrings_QtQuick[11971]
#define sipNameNr_image 11977
#define sipName_image &sipStrings_QtQuick[11977]
#define sipNameNr_None_ 11983
#define sipName_None_ &sipStrings_QtQuick[11983]
#define sipNameNr_Flags 686
#define sipName_Flags &sipStrings_QtQuick[686]
#define sipNameNr_Error 1619
#define sipName_Error &sipStrings_QtQuick[1619]
#define sipNameNr_width 11989
#define sipName_width &sipStrings_QtQuick[11989]
#define sipNameNr_count 11995
#define sipName_count &sipStrings_QtQuick[11995]
#define sipNameNr_flags 12001
#define sipName_flags &sipStrings_QtQuick[12001]
#define sipNameNr_event 12007
#define sipName_event &sipStrings_QtQuick[12007]
#define sipNameNr_state 12013
#define sipName_state &sipStrings_QtQuick[12013]
#define sipNameNr_HLSL 12019
#define sipName_HLSL &sipStrings_QtQuick[12019]
#define sipNameNr_GLSL 12024
#define sipName_GLSL &sipStrings_QtQuick[12024]
#define sipNameNr_Zero 12029
#define sipName_Zero &sipStrings_QtQuick[12029]
#define sipNameNr_grab 12034
#define sipName_grab &sipStrings_QtQuick[12034]
#define sipNameNr_Left 10713
#define sipName_Left &sipStrings_QtQuick[10713]
#define sipNameNr_setZ 12039
#define sipName_setZ &sipStrings_QtQuick[12039]
#define sipNameNr_bind 12044
#define sipName_bind &sipStrings_QtQuick[12044]
#define sipNameNr_item 12049
#define sipName_item &sipStrings_QtQuick[12049]
#define sipNameNr_rect 12054
#define sipName_rect &sipStrings_QtQuick[12054]
#define sipNameNr_clip 12059
#define sipName_clip &sipStrings_QtQuick[12059]
#define sipNameNr_sync 12064
#define sipName_sync &sipStrings_QtQuick[12064]
#define sipNameNr_setY 12069
#define sipName_setY &sipStrings_QtQuick[12069]
#define sipNameNr_setX 12074
#define sipName_setX &sipStrings_QtQuick[12074]
#define sipNameNr_Flag 279
#define sipName_Flag &sipStrings_QtQuick[279]
#define sipNameNr_Type 514
#define sipName_Type &sipStrings_QtQuick[514]
#define sipNameNr_Null 12079
#define sipName_Null &sipStrings_QtQuick[12079]
#define sipNameNr_size 12084
#define sipName_size &sipStrings_QtQuick[12084]
#define sipNameNr_type 12089
#define sipName_type &sipStrings_QtQuick[12089]
#define sipNameNr_One 12094
#define sipName_One &sipStrings_QtQuick[12094]
#define sipNameNr_set 6501
#define sipName_set &sipStrings_QtQuick[6501]
#define sipNameNr_Top 12098
#define sipName_Top &sipStrings_QtQuick[12098]
#define sipNameNr_get 1282
#define sipName_get &sipStrings_QtQuick[1282]
#define sipNameNr_url 12102
#define sipName_url &sipStrings_QtQuick[12102]
#define sipNameNr_ty 2370
#define sipName_ty &sipStrings_QtQuick[2370]
#define sipNameNr_tx 12106
#define sipName_tx &sipStrings_QtQuick[12106]
#define sipNameNr_on 1119
#define sipName_on &sipStrings_QtQuick[1119]
#define sipNameNr_B 12109
#define sipName_B &sipStrings_QtQuick[12109]
#define sipNameNr_G 11793
#define sipName_G &sipStrings_QtQuick[11793]
#define sipNameNr_R 12111
#define sipName_R &sipStrings_QtQuick[12111]
#define sipNameNr_A 12113
#define sipName_A &sipStrings_QtQuick[12113]
#define sipNameNr_g 282
#define sipName_g &sipStrings_QtQuick[282]
#define sipNameNr_r 119
#define sipName_r &sipStrings_QtQuick[119]
#define sipNameNr_z 12115
#define sipName_z &sipStrings_QtQuick[12115]
#define sipNameNr_x 4908
#define sipName_x &sipStrings_QtQuick[4908]
#define sipNameNr_y 2158
#define sipName_y &sipStrings_QtQuick[2158]
#define sipNameNr_b 5188
#define sipName_b &sipStrings_QtQuick[5188]
#define sipNameNr_a 1316
#define sipName_a &sipStrings_QtQuick[1316]

#define sipMalloc                   sipAPI_QtQuick->api_malloc
#define sipFree                     sipAPI_QtQuick->api_free
#define sipBuildResult              sipAPI_QtQuick->api_build_result
#define sipCallMethod               sipAPI_QtQuick->api_call_method
#define sipCallProcedureMethod      sipAPI_QtQuick->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtQuick->api_call_error_handler
#define sipParseResultEx            sipAPI_QtQuick->api_parse_result_ex
#define sipParseResult              sipAPI_QtQuick->api_parse_result
#define sipParseArgs                sipAPI_QtQuick->api_parse_args
#define sipParseKwdArgs             sipAPI_QtQuick->api_parse_kwd_args
#define sipParsePair                sipAPI_QtQuick->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtQuick->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtQuick->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtQuick->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtQuick->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtQuick->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtQuick->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtQuick->api_add_exception
#define sipNoFunction               sipAPI_QtQuick->api_no_function
#define sipNoMethod                 sipAPI_QtQuick->api_no_method
#define sipAbstractMethod           sipAPI_QtQuick->api_abstract_method
#define sipBadClass                 sipAPI_QtQuick->api_bad_class
#define sipBadCatcherResult         sipAPI_QtQuick->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtQuick->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtQuick->api_bad_operator_arg
#define sipTrace                    sipAPI_QtQuick->api_trace
#define sipTransferBack             sipAPI_QtQuick->api_transfer_back
#define sipTransferTo               sipAPI_QtQuick->api_transfer_to
#define sipTransferBreak            sipAPI_QtQuick->api_transfer_break
#define sipSimpleWrapper_Type       sipAPI_QtQuick->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtQuick->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtQuick->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtQuick->api_voidptr_type
#define sipGetPyObject              sipAPI_QtQuick->api_get_pyobject
#define sipGetAddress               sipAPI_QtQuick->api_get_address
#define sipGetMixinAddress          sipAPI_QtQuick->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtQuick->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtQuick->api_get_complex_cpp_ptr
#define sipIsPyMethod               sipAPI_QtQuick->api_is_py_method
#define sipCallHook                 sipAPI_QtQuick->api_call_hook
#define sipEndThread                sipAPI_QtQuick->api_end_thread
#define sipConnectRx                sipAPI_QtQuick->api_connect_rx
#define sipDisconnectRx             sipAPI_QtQuick->api_disconnect_rx
#define sipRaiseUnknownException    sipAPI_QtQuick->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtQuick->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtQuick->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtQuick->api_add_type_instance
#define sipFreeSipslot              sipAPI_QtQuick->api_free_sipslot
#define sipSameSlot                 sipAPI_QtQuick->api_same_slot
#define sipPySlotExtend             sipAPI_QtQuick->api_pyslot_extend
#define sipConvertRx                sipAPI_QtQuick->api_convert_rx
#define sipAddDelayedDtor           sipAPI_QtQuick->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtQuick->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtQuick->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtQuick->api_force_convert_to_type
#define sipCanConvertToEnum         sipAPI_QtQuick->api_can_convert_to_enum
#define sipConvertToEnum            sipAPI_QtQuick->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtQuick->api_convert_to_bool
#define sipReleaseType              sipAPI_QtQuick->api_release_type
#define sipConvertFromType          sipAPI_QtQuick->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtQuick->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtQuick->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtQuick->api_convert_from_enum
#define sipGetState                 sipAPI_QtQuick->api_get_state
#define sipExportSymbol             sipAPI_QtQuick->api_export_symbol
#define sipImportSymbol             sipAPI_QtQuick->api_import_symbol
#define sipFindType                 sipAPI_QtQuick->api_find_type
#define sipFindNamedEnum            sipAPI_QtQuick->api_find_named_enum
#define sipBytes_AsChar             sipAPI_QtQuick->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtQuick->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtQuick->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtQuick->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtQuick->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtQuick->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtQuick->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtQuick->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtQuick->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtQuick->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtQuick->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtQuick->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtQuick->api_convert_from_const_void_ptr_and_size
#define sipInvokeSlot               sipAPI_QtQuick->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtQuick->api_invoke_slot_ex
#define sipSaveSlot                 sipAPI_QtQuick->api_save_slot
#define sipClearAnySlotReference    sipAPI_QtQuick->api_clear_any_slot_reference
#define sipVisitSlot                sipAPI_QtQuick->api_visit_slot
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipDeprecated               sipAPI_QtQuick->api_deprecated
#define sipGetReference             sipAPI_QtQuick->api_get_reference
#define sipKeepReference            sipAPI_QtQuick->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtQuick->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtQuick->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtQuick->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtQuick->api_type_scope
#define sipResolveTypedef           sipAPI_QtQuick->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtQuick->api_register_attribute_getter
#define sipIsAPIEnabled             sipAPI_QtQuick->api_is_api_enabled
#define sipSetDestroyOnExit         sipAPI_QtQuick->api_set_destroy_on_exit
#define sipEnableAutoconversion     sipAPI_QtQuick->api_enable_autoconversion
#define sipEnableOverflowChecking   sipAPI_QtQuick->api_enable_overflow_checking
#define sipInitMixin                sipAPI_QtQuick->api_init_mixin
#define sipExportModule             sipAPI_QtQuick->api_export_module
#define sipInitModule               sipAPI_QtQuick->api_init_module
#define sipGetInterpreter           sipAPI_QtQuick->api_get_interpreter
#define sipSetNewUserTypeHandler    sipAPI_QtQuick->api_set_new_user_type_handler
#define sipSetTypeUserData          sipAPI_QtQuick->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtQuick->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtQuick->api_py_type_dict
#define sipPyTypeName               sipAPI_QtQuick->api_py_type_name
#define sipGetCFunction             sipAPI_QtQuick->api_get_c_function
#define sipGetMethod                sipAPI_QtQuick->api_get_method
#define sipFromMethod               sipAPI_QtQuick->api_from_method
#define sipGetDate                  sipAPI_QtQuick->api_get_date
#define sipFromDate                 sipAPI_QtQuick->api_from_date
#define sipGetDateTime              sipAPI_QtQuick->api_get_datetime
#define sipFromDateTime             sipAPI_QtQuick->api_from_datetime
#define sipGetTime                  sipAPI_QtQuick->api_get_time
#define sipFromTime                 sipAPI_QtQuick->api_from_time
#define sipIsUserType               sipAPI_QtQuick->api_is_user_type
#define sipGetFrame                 sipAPI_QtQuick->api_get_frame
#define sipCheckPluginForType       sipAPI_QtQuick->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtQuick->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtQuick->api_unicode_write
#define sipUnicodeData              sipAPI_QtQuick->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtQuick->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtQuick->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtQuick->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtQuick->api_is_derived_class
#define sipGetUserObject            sipAPI_QtQuick->api_get_user_object
#define sipSetUserObject            sipAPI_QtQuick->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtQuick->api_register_event_handler
#define sipLong_AsChar              sipAPI_QtQuick->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtQuick->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtQuick->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtQuick->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtQuick->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtQuick->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtQuick->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtQuick->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtQuick->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtQuick->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtQuick->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtQuick->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtQuick->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtQuick->api_register_exit_notifier

/* These are deprecated. */
#define sipMapStringToClass         sipAPI_QtQuick->api_map_string_to_class
#define sipMapIntToClass            sipAPI_QtQuick->api_map_int_to_class
#define sipFindClass                sipAPI_QtQuick->api_find_class
#define sipFindMappedType           sipAPI_QtQuick->api_find_mapped_type
#define sipConvertToArray           sipAPI_QtQuick->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtQuick->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtQuick->api_enable_gc
#define sipPrintObject              sipAPI_QtQuick->api_print_object
#define sipWrapper_Check(w)         PyObject_TypeCheck((w), sipAPI_QtQuick->api_wrapper_type)
#define sipGetWrapper(p, wt)        sipGetPyObject((p), (wt)->wt_td)
#define sipReleaseInstance(p, wt, s)    sipReleaseType((p), (wt)->wt_td, (s))
#define sipReleaseMappedType        sipReleaseType
#define sipCanConvertToInstance(o, wt, f)   sipCanConvertToType((o), (wt)->wt_td, (f))
#define sipCanConvertToMappedType   sipCanConvertToType
#define sipConvertToInstance(o, wt, t, f, s, e)     sipConvertToType((o), (wt)->wt_td, (t), (f), (s), (e))
#define sipConvertToMappedType      sipConvertToType
#define sipForceConvertToInstance(o, wt, t, f, s, e)    sipForceConvertToType((o), (wt)->wt_td, (t), (f), (s), (e))
#define sipForceConvertToMappedType sipForceConvertToType
#define sipConvertFromInstance(p, wt, t)    sipConvertFromType((p), (wt)->wt_td, (t))
#define sipConvertFromMappedType    sipConvertFromType
#define sipConvertFromNamedEnum(v, pt)  sipConvertFromEnum((v), ((sipEnumTypeObject *)(pt))->type)
#define sipConvertFromNewInstance(p, wt, t) sipConvertFromNewType((p), (wt)->wt_td, (t))

/* The strings used by this module. */
extern const char sipStrings_QtQuick[];

#define sipType_QQuickItem sipExportedTypes_QtQuick[7]
#define sipClass_QQuickItem sipExportedTypes_QtQuick[7]->u.td_wrapper_type

#define sipType_QQuickItem_TransformOrigin sipExportedTypes_QtQuick[12]
#define sipEnum_QQuickItem_TransformOrigin sipExportedTypes_QtQuick[12]->u.td_py_type

#define sipType_QQuickItem_ItemChange sipExportedTypes_QtQuick[10]
#define sipEnum_QQuickItem_ItemChange sipExportedTypes_QtQuick[10]->u.td_py_type

#define sipType_QQuickItem_Flag sipExportedTypes_QtQuick[8]
#define sipEnum_QQuickItem_Flag sipExportedTypes_QtQuick[8]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickItem;
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 1925 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipAPIQtQuick.h"


class sipQQuickItem : public  ::QQuickItem
{
public:
    sipQQuickItem( ::QQuickItem*);
    virtual ~sipQQuickItem();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void updatePolish() SIP_OVERRIDE;
    void releaseResources() SIP_OVERRIDE;
     ::QSGNode* updatePaintNode( ::QSGNode*, ::QQuickItem::UpdatePaintNodeData*) SIP_OVERRIDE;
    void geometryChanged(const  ::QRectF&,const  ::QRectF&) SIP_OVERRIDE;
    bool childMouseEventFilter( ::QQuickItem*, ::QEvent*) SIP_OVERRIDE;
    void dropEvent( ::QDropEvent*) SIP_OVERRIDE;
    void dragLeaveEvent( ::QDragLeaveEvent*) SIP_OVERRIDE;
    void dragMoveEvent( ::QDragMoveEvent*) SIP_OVERRIDE;
    void dragEnterEvent( ::QDragEnterEvent*) SIP_OVERRIDE;
    void hoverLeaveEvent( ::QHoverEvent*) SIP_OVERRIDE;
    void hoverMoveEvent( ::QHoverEvent*) SIP_OVERRIDE;
    void hoverEnterEvent( ::QHoverEvent*) SIP_OVERRIDE;
    void touchEvent( ::QTouchEvent*) SIP_OVERRIDE;
    void wheelEvent( ::QWheelEvent*) SIP_OVERRIDE;
    void touchUngrabEvent() SIP_OVERRIDE;
    void mouseUngrabEvent() SIP_OVERRIDE;
    void mouseDoubleClickEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void focusOutEvent( ::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent( ::QFocusEvent*) SIP_OVERRIDE;
    void inputMethodEvent( ::QInputMethodEvent*) SIP_OVERRIDE;
    void keyReleaseEvent( ::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent( ::QKeyEvent*) SIP_OVERRIDE;
    void itemChange( ::QQuickItem::ItemChange,const  ::QQuickItem::ItemChangeData&) SIP_OVERRIDE;
     ::QSGTextureProvider* textureProvider() const SIP_OVERRIDE;
    bool isTextureProvider() const SIP_OVERRIDE;
     ::QVariant inputMethodQuery( ::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool contains(const  ::QPointF&) const SIP_OVERRIDE;
    void classBegin() SIP_OVERRIDE;
    void componentComplete() SIP_OVERRIDE;
    bool event( ::QEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickItem(const sipQQuickItem &);
    sipQQuickItem &operator = (const sipQQuickItem &);

    char sipPyMethods[39];
};

#define sipType_QQuickFramebufferObject sipExportedTypes_QtQuick[3]
#define sipClass_QQuickFramebufferObject sipExportedTypes_QtQuick[3]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickFramebufferObject;
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickframebufferobject.sip"
#include <qquickframebufferobject.h>
#line 1999 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipAPIQtQuick.h"


class sipQQuickFramebufferObject : public  ::QQuickFramebufferObject
{
public:
    sipQQuickFramebufferObject( ::QQuickItem*);
    virtual ~sipQQuickFramebufferObject();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
     ::QQuickFramebufferObject::Renderer* createRenderer() const SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event( ::QEvent*) SIP_OVERRIDE;
    void componentComplete() SIP_OVERRIDE;
    void classBegin() SIP_OVERRIDE;
    bool contains(const  ::QPointF&) const SIP_OVERRIDE;
     ::QVariant inputMethodQuery( ::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool isTextureProvider() const SIP_OVERRIDE;
     ::QSGTextureProvider* textureProvider() const SIP_OVERRIDE;
    void itemChange( ::QQuickItem::ItemChange,const  ::QQuickItem::ItemChangeData&) SIP_OVERRIDE;
    void keyPressEvent( ::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent( ::QKeyEvent*) SIP_OVERRIDE;
    void inputMethodEvent( ::QInputMethodEvent*) SIP_OVERRIDE;
    void focusInEvent( ::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent( ::QFocusEvent*) SIP_OVERRIDE;
    void mousePressEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseUngrabEvent() SIP_OVERRIDE;
    void touchUngrabEvent() SIP_OVERRIDE;
    void wheelEvent( ::QWheelEvent*) SIP_OVERRIDE;
    void touchEvent( ::QTouchEvent*) SIP_OVERRIDE;
    void hoverEnterEvent( ::QHoverEvent*) SIP_OVERRIDE;
    void hoverMoveEvent( ::QHoverEvent*) SIP_OVERRIDE;
    void hoverLeaveEvent( ::QHoverEvent*) SIP_OVERRIDE;
    void dragEnterEvent( ::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent( ::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent( ::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent( ::QDropEvent*) SIP_OVERRIDE;
    bool childMouseEventFilter( ::QQuickItem*, ::QEvent*) SIP_OVERRIDE;
    void geometryChanged(const  ::QRectF&,const  ::QRectF&) SIP_OVERRIDE;
     ::QSGNode* updatePaintNode( ::QSGNode*, ::QQuickItem::UpdatePaintNodeData*) SIP_OVERRIDE;
    void releaseResources() SIP_OVERRIDE;
    void updatePolish() SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickFramebufferObject(const sipQQuickFramebufferObject &);
    sipQQuickFramebufferObject &operator = (const sipQQuickFramebufferObject &);

    char sipPyMethods[40];
};

#define sipType_QQuickFramebufferObject_Renderer sipExportedTypes_QtQuick[4]
#define sipClass_QQuickFramebufferObject_Renderer sipExportedTypes_QtQuick[4]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickFramebufferObject_Renderer;

#define sipType_QQuickTextureFactory sipExportedTypes_QtQuick[21]
#define sipClass_QQuickTextureFactory sipExportedTypes_QtQuick[21]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickTextureFactory;

#define sipType_QQuickImageProvider sipExportedTypes_QtQuick[5]
#define sipClass_QQuickImageProvider sipExportedTypes_QtQuick[5]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickImageProvider;

#define sipType_QQuickImageResponse sipExportedTypes_QtQuick[6]
#define sipClass_QQuickImageResponse sipExportedTypes_QtQuick[6]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickImageResponse;

#define sipType_QQuickAsyncImageProvider sipExportedTypes_QtQuick[1]
#define sipClass_QQuickAsyncImageProvider sipExportedTypes_QtQuick[1]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickAsyncImageProvider;

#define sipType_QQuickItem_Flags sipExportedTypes_QtQuick[9]
#define sipClass_QQuickItem_Flags sipExportedTypes_QtQuick[9]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickItem_Flags;

#define sipType_QQuickItem_ItemChangeData sipExportedTypes_QtQuick[11]
#define sipClass_QQuickItem_ItemChangeData sipExportedTypes_QtQuick[11]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickItem_ItemChangeData;

#define sipType_QQuickItem_UpdatePaintNodeData sipExportedTypes_QtQuick[13]
#define sipClass_QQuickItem_UpdatePaintNodeData sipExportedTypes_QtQuick[13]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickItem_UpdatePaintNodeData;

#define sipType_QQuickItemGrabResult sipExportedTypes_QtQuick[14]
#define sipClass_QQuickItemGrabResult sipExportedTypes_QtQuick[14]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickItemGrabResult;

#define sipType_QQuickPaintedItem sipExportedTypes_QtQuick[15]
#define sipClass_QQuickPaintedItem sipExportedTypes_QtQuick[15]->u.td_wrapper_type

#define sipType_QQuickPaintedItem_PerformanceHint sipExportedTypes_QtQuick[16]
#define sipEnum_QQuickPaintedItem_PerformanceHint sipExportedTypes_QtQuick[16]->u.td_py_type

#define sipType_QQuickPaintedItem_RenderTarget sipExportedTypes_QtQuick[18]
#define sipEnum_QQuickPaintedItem_RenderTarget sipExportedTypes_QtQuick[18]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickPaintedItem;
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickpainteditem.sip"
#include <qquickpainteditem.h>
#line 2125 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipAPIQtQuick.h"


class sipQQuickPaintedItem : public  ::QQuickPaintedItem
{
public:
    sipQQuickPaintedItem( ::QQuickItem*);
    virtual ~sipQQuickPaintedItem();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void paint( ::QPainter*) SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event( ::QEvent*) SIP_OVERRIDE;
    void componentComplete() SIP_OVERRIDE;
    void classBegin() SIP_OVERRIDE;
    bool contains(const  ::QPointF&) const SIP_OVERRIDE;
     ::QVariant inputMethodQuery( ::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool isTextureProvider() const SIP_OVERRIDE;
     ::QSGTextureProvider* textureProvider() const SIP_OVERRIDE;
    void itemChange( ::QQuickItem::ItemChange,const  ::QQuickItem::ItemChangeData&) SIP_OVERRIDE;
    void keyPressEvent( ::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent( ::QKeyEvent*) SIP_OVERRIDE;
    void inputMethodEvent( ::QInputMethodEvent*) SIP_OVERRIDE;
    void focusInEvent( ::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent( ::QFocusEvent*) SIP_OVERRIDE;
    void mousePressEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseUngrabEvent() SIP_OVERRIDE;
    void touchUngrabEvent() SIP_OVERRIDE;
    void wheelEvent( ::QWheelEvent*) SIP_OVERRIDE;
    void touchEvent( ::QTouchEvent*) SIP_OVERRIDE;
    void hoverEnterEvent( ::QHoverEvent*) SIP_OVERRIDE;
    void hoverMoveEvent( ::QHoverEvent*) SIP_OVERRIDE;
    void hoverLeaveEvent( ::QHoverEvent*) SIP_OVERRIDE;
    void dragEnterEvent( ::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent( ::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent( ::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent( ::QDropEvent*) SIP_OVERRIDE;
    bool childMouseEventFilter( ::QQuickItem*, ::QEvent*) SIP_OVERRIDE;
    void geometryChanged(const  ::QRectF&,const  ::QRectF&) SIP_OVERRIDE;
     ::QSGNode* updatePaintNode( ::QSGNode*, ::QQuickItem::UpdatePaintNodeData*) SIP_OVERRIDE;
    void releaseResources() SIP_OVERRIDE;
    void updatePolish() SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickPaintedItem(const sipQQuickPaintedItem &);
    sipQQuickPaintedItem &operator = (const sipQQuickPaintedItem &);

    char sipPyMethods[40];
};

#define sipType_QQuickPaintedItem_PerformanceHints sipExportedTypes_QtQuick[17]
#define sipClass_QQuickPaintedItem_PerformanceHints sipExportedTypes_QtQuick[17]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickPaintedItem_PerformanceHints;

#define sipType_QQuickRenderControl sipExportedTypes_QtQuick[19]
#define sipClass_QQuickRenderControl sipExportedTypes_QtQuick[19]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickRenderControl;

#define sipType_QQuickTextDocument sipExportedTypes_QtQuick[20]
#define sipClass_QQuickTextDocument sipExportedTypes_QtQuick[20]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickTextDocument;

#define sipType_QQuickWindow sipExportedTypes_QtQuick[25]
#define sipClass_QQuickWindow sipExportedTypes_QtQuick[25]->u.td_wrapper_type

#define sipType_QQuickWindow_NativeObjectType sipExportedTypes_QtQuick[28]
#define sipEnum_QQuickWindow_NativeObjectType sipExportedTypes_QtQuick[28]->u.td_py_type

#define sipType_QQuickWindow_TextRenderType sipExportedTypes_QtQuick[31]
#define sipEnum_QQuickWindow_TextRenderType sipExportedTypes_QtQuick[31]->u.td_py_type

#define sipType_QQuickWindow_RenderStage sipExportedTypes_QtQuick[29]
#define sipEnum_QQuickWindow_RenderStage sipExportedTypes_QtQuick[29]->u.td_py_type

#define sipType_QQuickWindow_SceneGraphError sipExportedTypes_QtQuick[30]
#define sipEnum_QQuickWindow_SceneGraphError sipExportedTypes_QtQuick[30]->u.td_py_type

#define sipType_QQuickWindow_CreateTextureOption sipExportedTypes_QtQuick[26]
#define sipEnum_QQuickWindow_CreateTextureOption sipExportedTypes_QtQuick[26]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickWindow;
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickwindow.sip"
#include <qquickwindow.h>
#line 2230 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipAPIQtQuick.h"


class sipQQuickWindow : public  ::QQuickWindow
{
public:
    sipQQuickWindow( ::QWindow*);
    virtual ~sipQQuickWindow();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event( ::QEvent*) SIP_OVERRIDE;
     ::QSize size() const SIP_OVERRIDE;
     ::QSurface::SurfaceType surfaceType() const SIP_OVERRIDE;
     ::QSurfaceFormat format() const SIP_OVERRIDE;
     ::QObject* focusObject() const SIP_OVERRIDE;
    void exposeEvent( ::QExposeEvent*) SIP_OVERRIDE;
    void resizeEvent( ::QResizeEvent*) SIP_OVERRIDE;
    void moveEvent( ::QMoveEvent*) SIP_OVERRIDE;
    void focusInEvent( ::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent( ::QFocusEvent*) SIP_OVERRIDE;
    void showEvent( ::QShowEvent*) SIP_OVERRIDE;
    void hideEvent( ::QHideEvent*) SIP_OVERRIDE;
    void keyPressEvent( ::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent( ::QKeyEvent*) SIP_OVERRIDE;
    void mousePressEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void wheelEvent( ::QWheelEvent*) SIP_OVERRIDE;
    void touchEvent( ::QTouchEvent*) SIP_OVERRIDE;
    void tabletEvent( ::QTabletEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickWindow(const sipQQuickWindow &);
    sipQQuickWindow &operator = (const sipQQuickWindow &);

    char sipPyMethods[27];
};

#define sipType_QQuickView sipExportedTypes_QtQuick[22]
#define sipClass_QQuickView sipExportedTypes_QtQuick[22]->u.td_wrapper_type

#define sipType_QQuickView_Status sipExportedTypes_QtQuick[24]
#define sipEnum_QQuickView_Status sipExportedTypes_QtQuick[24]->u.td_py_type

#define sipType_QQuickView_ResizeMode sipExportedTypes_QtQuick[23]
#define sipEnum_QQuickView_ResizeMode sipExportedTypes_QtQuick[23]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickView;
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickview.sip"
#include <qquickview.h>
#line 2298 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipAPIQtQuick.h"


class sipQQuickView : public  ::QQuickView
{
public:
    sipQQuickView( ::QWindow*);
    sipQQuickView( ::QQmlEngine*, ::QWindow*);
    sipQQuickView(const  ::QUrl&, ::QWindow*);
    virtual ~sipQQuickView();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void tabletEvent( ::QTabletEvent*) SIP_OVERRIDE;
    void touchEvent( ::QTouchEvent*) SIP_OVERRIDE;
    void wheelEvent( ::QWheelEvent*) SIP_OVERRIDE;
    void mouseMoveEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent( ::QMouseEvent*) SIP_OVERRIDE;
    void keyReleaseEvent( ::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent( ::QKeyEvent*) SIP_OVERRIDE;
    void hideEvent( ::QHideEvent*) SIP_OVERRIDE;
    void showEvent( ::QShowEvent*) SIP_OVERRIDE;
    void focusOutEvent( ::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent( ::QFocusEvent*) SIP_OVERRIDE;
    void moveEvent( ::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent( ::QResizeEvent*) SIP_OVERRIDE;
    void exposeEvent( ::QExposeEvent*) SIP_OVERRIDE;
     ::QObject* focusObject() const SIP_OVERRIDE;
     ::QSurfaceFormat format() const SIP_OVERRIDE;
     ::QSurface::SurfaceType surfaceType() const SIP_OVERRIDE;
     ::QSize size() const SIP_OVERRIDE;
    bool event( ::QEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQuickView(const sipQQuickView &);
    sipQQuickView &operator = (const sipQQuickView &);

    char sipPyMethods[27];
};

#define sipType_QQuickWindow_CreateTextureOptions sipExportedTypes_QtQuick[27]
#define sipClass_QQuickWindow_CreateTextureOptions sipExportedTypes_QtQuick[27]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickWindow_CreateTextureOptions;

#define sipType_QQuickCloseEvent sipExportedTypes_QtQuick[2]
#define sipClass_QQuickCloseEvent sipExportedTypes_QtQuick[2]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QQuickCloseEvent;

#define sipType_QSGAbstractRenderer sipExportedTypes_QtQuick[32]
#define sipClass_QSGAbstractRenderer sipExportedTypes_QtQuick[32]->u.td_wrapper_type

#define sipType_QSGAbstractRenderer_MatrixTransformFlag sipExportedTypes_QtQuick[35]
#define sipEnum_QSGAbstractRenderer_MatrixTransformFlag sipExportedTypes_QtQuick[35]->u.td_py_type

#define sipType_QSGAbstractRenderer_ClearModeBit sipExportedTypes_QtQuick[34]
#define sipEnum_QSGAbstractRenderer_ClearModeBit sipExportedTypes_QtQuick[34]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGAbstractRenderer;

#define sipType_QSGAbstractRenderer_ClearMode sipExportedTypes_QtQuick[33]
#define sipClass_QSGAbstractRenderer_ClearMode sipExportedTypes_QtQuick[33]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGAbstractRenderer_ClearMode;

#define sipType_QSGAbstractRenderer_MatrixTransformFlags sipExportedTypes_QtQuick[36]
#define sipClass_QSGAbstractRenderer_MatrixTransformFlags sipExportedTypes_QtQuick[36]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGAbstractRenderer_MatrixTransformFlags;

#define sipType_QSGEngine sipExportedTypes_QtQuick[40]
#define sipClass_QSGEngine sipExportedTypes_QtQuick[40]->u.td_wrapper_type

#define sipType_QSGEngine_CreateTextureOption sipExportedTypes_QtQuick[41]
#define sipEnum_QSGEngine_CreateTextureOption sipExportedTypes_QtQuick[41]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGEngine;

#define sipType_QSGEngine_CreateTextureOptions sipExportedTypes_QtQuick[42]
#define sipClass_QSGEngine_CreateTextureOptions sipExportedTypes_QtQuick[42]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGEngine_CreateTextureOptions;

#define sipType_QSGMaterial sipExportedTypes_QtQuick[58]
#define sipClass_QSGMaterial sipExportedTypes_QtQuick[58]->u.td_wrapper_type

#define sipType_QSGMaterial_Flag sipExportedTypes_QtQuick[59]
#define sipEnum_QSGMaterial_Flag sipExportedTypes_QtQuick[59]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGMaterial;

#define sipType_QSGFlatColorMaterial sipExportedTypes_QtQuick[43]
#define sipClass_QSGFlatColorMaterial sipExportedTypes_QtQuick[43]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGFlatColorMaterial;

#define sipType_QSGGeometry sipExportedTypes_QtQuick[44]
#define sipClass_QSGGeometry sipExportedTypes_QtQuick[44]->u.td_wrapper_type

#define sipType_QSGGeometry_Type sipExportedTypes_QtQuick[53]
#define sipEnum_QSGGeometry_Type sipExportedTypes_QtQuick[53]->u.td_py_type

#define sipType_QSGGeometry_DrawingMode sipExportedTypes_QtQuick[50]
#define sipEnum_QSGGeometry_DrawingMode sipExportedTypes_QtQuick[50]->u.td_py_type

#define sipType_QSGGeometry_AttributeType sipExportedTypes_QtQuick[47]
#define sipEnum_QSGGeometry_AttributeType sipExportedTypes_QtQuick[47]->u.td_py_type

#define sipType_QSGGeometry_DataPattern sipExportedTypes_QtQuick[49]
#define sipEnum_QSGGeometry_DataPattern sipExportedTypes_QtQuick[49]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGGeometry;

#define sipType_QSGGeometry_Attribute sipExportedTypes_QtQuick[45]
#define sipClass_QSGGeometry_Attribute sipExportedTypes_QtQuick[45]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGGeometry_Attribute;

#define sipType_QSGGeometry_AttributeSet sipExportedTypes_QtQuick[46]
#define sipClass_QSGGeometry_AttributeSet sipExportedTypes_QtQuick[46]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGGeometry_AttributeSet;

#define sipType_QSGGeometry_Point2D sipExportedTypes_QtQuick[51]
#define sipClass_QSGGeometry_Point2D sipExportedTypes_QtQuick[51]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGGeometry_Point2D;

#define sipType_QSGGeometry_TexturedPoint2D sipExportedTypes_QtQuick[52]
#define sipClass_QSGGeometry_TexturedPoint2D sipExportedTypes_QtQuick[52]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGGeometry_TexturedPoint2D;

#define sipType_QSGGeometry_ColoredPoint2D sipExportedTypes_QtQuick[48]
#define sipClass_QSGGeometry_ColoredPoint2D sipExportedTypes_QtQuick[48]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGGeometry_ColoredPoint2D;

#define sipType_QSGNode sipExportedTypes_QtQuick[75]
#define sipClass_QSGNode sipExportedTypes_QtQuick[75]->u.td_wrapper_type

#define sipType_QSGNode_DirtyStateBit sipExportedTypes_QtQuick[77]
#define sipEnum_QSGNode_DirtyStateBit sipExportedTypes_QtQuick[77]->u.td_py_type

#define sipType_QSGNode_Flag sipExportedTypes_QtQuick[78]
#define sipEnum_QSGNode_Flag sipExportedTypes_QtQuick[78]->u.td_py_type

#define sipType_QSGNode_NodeType sipExportedTypes_QtQuick[80]
#define sipEnum_QSGNode_NodeType sipExportedTypes_QtQuick[80]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGNode;

#define sipType_QSGBasicGeometryNode sipExportedTypes_QtQuick[37]
#define sipClass_QSGBasicGeometryNode sipExportedTypes_QtQuick[37]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGBasicGeometryNode;

#define sipType_QSGGeometryNode sipExportedTypes_QtQuick[54]
#define sipClass_QSGGeometryNode sipExportedTypes_QtQuick[54]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGGeometryNode;

#define sipType_QSGImageNode sipExportedTypes_QtQuick[55]
#define sipClass_QSGImageNode sipExportedTypes_QtQuick[55]->u.td_wrapper_type

#define sipType_QSGImageNode_TextureCoordinatesTransformFlag sipExportedTypes_QtQuick[56]
#define sipEnum_QSGImageNode_TextureCoordinatesTransformFlag sipExportedTypes_QtQuick[56]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGImageNode;

#define sipType_QSGImageNode_TextureCoordinatesTransformMode sipExportedTypes_QtQuick[57]
#define sipClass_QSGImageNode_TextureCoordinatesTransformMode sipExportedTypes_QtQuick[57]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGImageNode_TextureCoordinatesTransformMode;

#define sipType_QSGMaterialShader sipExportedTypes_QtQuick[70]
#define sipClass_QSGMaterialShader sipExportedTypes_QtQuick[70]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialShader;

#define sipType_QSGMaterialShader_RenderState sipExportedTypes_QtQuick[71]
#define sipClass_QSGMaterialShader_RenderState sipExportedTypes_QtQuick[71]->u.td_wrapper_type

#define sipType_QSGMaterialShader_RenderState_DirtyState sipExportedTypes_QtQuick[72]
#define sipEnum_QSGMaterialShader_RenderState_DirtyState sipExportedTypes_QtQuick[72]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialShader_RenderState;

#define sipType_QSGMaterialShader_RenderState_DirtyStates sipExportedTypes_QtQuick[73]
#define sipClass_QSGMaterialShader_RenderState_DirtyStates sipExportedTypes_QtQuick[73]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialShader_RenderState_DirtyStates;

#define sipType_QSGMaterialType sipExportedTypes_QtQuick[74]
#define sipClass_QSGMaterialType sipExportedTypes_QtQuick[74]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialType;

#define sipType_QSGMaterial_Flags sipExportedTypes_QtQuick[60]
#define sipClass_QSGMaterial_Flags sipExportedTypes_QtQuick[60]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGMaterial_Flags;

#define sipType_QSGMaterialRhiShader sipExportedTypes_QtQuick[61]
#define sipClass_QSGMaterialRhiShader sipExportedTypes_QtQuick[61]->u.td_wrapper_type

#define sipType_QSGMaterialRhiShader_Flag sipExportedTypes_QtQuick[62]
#define sipEnum_QSGMaterialRhiShader_Flag sipExportedTypes_QtQuick[62]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialRhiShader;

#define sipType_QSGMaterialRhiShader_RenderState sipExportedTypes_QtQuick[69]
#define sipClass_QSGMaterialRhiShader_RenderState sipExportedTypes_QtQuick[69]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialRhiShader_RenderState;

#define sipType_QSGMaterialRhiShader_GraphicsPipelineState sipExportedTypes_QtQuick[64]
#define sipClass_QSGMaterialRhiShader_GraphicsPipelineState sipExportedTypes_QtQuick[64]->u.td_wrapper_type

#define sipType_QSGMaterialRhiShader_GraphicsPipelineState_CullMode sipExportedTypes_QtQuick[68]
#define sipEnum_QSGMaterialRhiShader_GraphicsPipelineState_CullMode sipExportedTypes_QtQuick[68]->u.td_py_type

#define sipType_QSGMaterialRhiShader_GraphicsPipelineState_ColorMaskComponent sipExportedTypes_QtQuick[67]
#define sipEnum_QSGMaterialRhiShader_GraphicsPipelineState_ColorMaskComponent sipExportedTypes_QtQuick[67]->u.td_py_type

#define sipType_QSGMaterialRhiShader_GraphicsPipelineState_BlendFactor sipExportedTypes_QtQuick[65]
#define sipEnum_QSGMaterialRhiShader_GraphicsPipelineState_BlendFactor sipExportedTypes_QtQuick[65]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialRhiShader_GraphicsPipelineState;

#define sipType_QSGMaterialRhiShader_GraphicsPipelineState_ColorMask sipExportedTypes_QtQuick[66]
#define sipClass_QSGMaterialRhiShader_GraphicsPipelineState_ColorMask sipExportedTypes_QtQuick[66]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialRhiShader_GraphicsPipelineState_ColorMask;

#define sipType_QSGMaterialRhiShader_Flags sipExportedTypes_QtQuick[63]
#define sipClass_QSGMaterialRhiShader_Flags sipExportedTypes_QtQuick[63]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGMaterialRhiShader_Flags;

#define sipType_QSGNode_Flags sipExportedTypes_QtQuick[79]
#define sipClass_QSGNode_Flags sipExportedTypes_QtQuick[79]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGNode_Flags;

#define sipType_QSGNode_DirtyState sipExportedTypes_QtQuick[76]
#define sipClass_QSGNode_DirtyState sipExportedTypes_QtQuick[76]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGNode_DirtyState;

#define sipType_QSGClipNode sipExportedTypes_QtQuick[38]
#define sipClass_QSGClipNode sipExportedTypes_QtQuick[38]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGClipNode;

#define sipType_QSGTransformNode sipExportedTypes_QtQuick[109]
#define sipClass_QSGTransformNode sipExportedTypes_QtQuick[109]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGTransformNode;

#define sipType_QSGOpacityNode sipExportedTypes_QtQuick[81]
#define sipClass_QSGOpacityNode sipExportedTypes_QtQuick[81]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGOpacityNode;

#define sipType_QSGRectangleNode sipExportedTypes_QtQuick[83]
#define sipClass_QSGRectangleNode sipExportedTypes_QtQuick[83]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGRectangleNode;

#define sipType_QSGRendererInterface sipExportedTypes_QtQuick[90]
#define sipClass_QSGRendererInterface sipExportedTypes_QtQuick[90]->u.td_wrapper_type

#define sipType_QSGRendererInterface_ShaderSourceType sipExportedTypes_QtQuick[95]
#define sipEnum_QSGRendererInterface_ShaderSourceType sipExportedTypes_QtQuick[95]->u.td_py_type

#define sipType_QSGRendererInterface_ShaderCompilationType sipExportedTypes_QtQuick[93]
#define sipEnum_QSGRendererInterface_ShaderCompilationType sipExportedTypes_QtQuick[93]->u.td_py_type

#define sipType_QSGRendererInterface_ShaderType sipExportedTypes_QtQuick[97]
#define sipEnum_QSGRendererInterface_ShaderType sipExportedTypes_QtQuick[97]->u.td_py_type

#define sipType_QSGRendererInterface_Resource sipExportedTypes_QtQuick[92]
#define sipEnum_QSGRendererInterface_Resource sipExportedTypes_QtQuick[92]->u.td_py_type

#define sipType_QSGRendererInterface_GraphicsApi sipExportedTypes_QtQuick[91]
#define sipEnum_QSGRendererInterface_GraphicsApi sipExportedTypes_QtQuick[91]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGRendererInterface;

#define sipType_QSGRendererInterface_ShaderCompilationTypes sipExportedTypes_QtQuick[94]
#define sipClass_QSGRendererInterface_ShaderCompilationTypes sipExportedTypes_QtQuick[94]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGRendererInterface_ShaderCompilationTypes;

#define sipType_QSGRendererInterface_ShaderSourceTypes sipExportedTypes_QtQuick[96]
#define sipClass_QSGRendererInterface_ShaderSourceTypes sipExportedTypes_QtQuick[96]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGRendererInterface_ShaderSourceTypes;

#define sipType_QSGRenderNode sipExportedTypes_QtQuick[84]
#define sipClass_QSGRenderNode sipExportedTypes_QtQuick[84]->u.td_wrapper_type

#define sipType_QSGRenderNode_RenderingFlag sipExportedTypes_QtQuick[86]
#define sipEnum_QSGRenderNode_RenderingFlag sipExportedTypes_QtQuick[86]->u.td_py_type

#define sipType_QSGRenderNode_StateFlag sipExportedTypes_QtQuick[88]
#define sipEnum_QSGRenderNode_StateFlag sipExportedTypes_QtQuick[88]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGRenderNode;

#define sipType_QSGRenderNode_StateFlags sipExportedTypes_QtQuick[89]
#define sipClass_QSGRenderNode_StateFlags sipExportedTypes_QtQuick[89]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGRenderNode_StateFlags;

#define sipType_QSGRenderNode_RenderingFlags sipExportedTypes_QtQuick[87]
#define sipClass_QSGRenderNode_RenderingFlags sipExportedTypes_QtQuick[87]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGRenderNode_RenderingFlags;

#define sipType_QSGRenderNode_RenderState sipExportedTypes_QtQuick[85]
#define sipClass_QSGRenderNode_RenderState sipExportedTypes_QtQuick[85]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGRenderNode_RenderState;

#define sipType_QSGSimpleRectNode sipExportedTypes_QtQuick[98]
#define sipClass_QSGSimpleRectNode sipExportedTypes_QtQuick[98]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGSimpleRectNode;

#define sipType_QSGSimpleTextureNode sipExportedTypes_QtQuick[99]
#define sipClass_QSGSimpleTextureNode sipExportedTypes_QtQuick[99]->u.td_wrapper_type

#define sipType_QSGSimpleTextureNode_TextureCoordinatesTransformFlag sipExportedTypes_QtQuick[100]
#define sipEnum_QSGSimpleTextureNode_TextureCoordinatesTransformFlag sipExportedTypes_QtQuick[100]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGSimpleTextureNode;

#define sipType_QSGSimpleTextureNode_TextureCoordinatesTransformMode sipExportedTypes_QtQuick[101]
#define sipClass_QSGSimpleTextureNode_TextureCoordinatesTransformMode sipExportedTypes_QtQuick[101]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGSimpleTextureNode_TextureCoordinatesTransformMode;

#define sipType_QSGTexture sipExportedTypes_QtQuick[102]
#define sipClass_QSGTexture sipExportedTypes_QtQuick[102]->u.td_wrapper_type

#define sipType_QSGTexture_AnisotropyLevel sipExportedTypes_QtQuick[103]
#define sipEnum_QSGTexture_AnisotropyLevel sipExportedTypes_QtQuick[103]->u.td_py_type

#define sipType_QSGTexture_Filtering sipExportedTypes_QtQuick[104]
#define sipEnum_QSGTexture_Filtering sipExportedTypes_QtQuick[104]->u.td_py_type

#define sipType_QSGTexture_WrapMode sipExportedTypes_QtQuick[106]
#define sipEnum_QSGTexture_WrapMode sipExportedTypes_QtQuick[106]->u.td_py_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGTexture;

#define sipType_QSGTexture_NativeTexture sipExportedTypes_QtQuick[105]
#define sipClass_QSGTexture_NativeTexture sipExportedTypes_QtQuick[105]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGTexture_NativeTexture;

#define sipType_QSGDynamicTexture sipExportedTypes_QtQuick[39]
#define sipClass_QSGDynamicTexture sipExportedTypes_QtQuick[39]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGDynamicTexture;

#define sipType_QSGOpaqueTextureMaterial sipExportedTypes_QtQuick[82]
#define sipClass_QSGOpaqueTextureMaterial sipExportedTypes_QtQuick[82]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGOpaqueTextureMaterial;

#define sipType_QSGTextureMaterial sipExportedTypes_QtQuick[107]
#define sipClass_QSGTextureMaterial sipExportedTypes_QtQuick[107]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGTextureMaterial;

#define sipType_QSGTextureProvider sipExportedTypes_QtQuick[108]
#define sipClass_QSGTextureProvider sipExportedTypes_QtQuick[108]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGTextureProvider;

#define sipType_QSGVertexColorMaterial sipExportedTypes_QtQuick[110]
#define sipClass_QSGVertexColorMaterial sipExportedTypes_QtQuick[110]->u.td_wrapper_type

extern sipClassTypeDef sipTypeDef_QtQuick_QSGVertexColorMaterial;

#define sipType_QList_0101QQuickItem sipExportedTypes_QtQuick[0]

extern sipMappedTypeDef sipTypeDef_QtQuick_QList_0101QQuickItem;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtQuick;
extern sipExportedModuleDef sipModuleAPI_QtQuick;
extern sipTypeDef *sipExportedTypes_QtQuick[];

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtQuick_QtCore[22].it_td
#define sipEnum_Qt_InputMethodQuery sipImportedTypes_QtQuick_QtCore[22].it_td->u.td_py_type

#define sipType_Qt_FocusReason sipImportedTypes_QtQuick_QtCore[20].it_td
#define sipEnum_Qt_FocusReason sipImportedTypes_QtQuick_QtCore[20].it_td->u.td_py_type

#define sipType_Qt_MouseButtons sipImportedTypes_QtQuick_QtCore[23].it_td
#define sipClass_Qt_MouseButtons sipImportedTypes_QtQuick_QtCore[23].it_td->u.td_wrapper_type

#define sipType_Qt_InputMethodQueries sipImportedTypes_QtQuick_QtCore[21].it_td
#define sipClass_Qt_InputMethodQueries sipImportedTypes_QtQuick_QtCore[21].it_td->u.td_wrapper_type

#define sipType_QObject sipImportedTypes_QtQuick_QtCore[4].it_td
#define sipClass_QObject sipImportedTypes_QtQuick_QtCore[4].it_td->u.td_wrapper_type

#define sipType_QByteArray sipImportedTypes_QtQuick_QtCore[0].it_td
#define sipClass_QByteArray sipImportedTypes_QtQuick_QtCore[0].it_td->u.td_wrapper_type

#define sipType_QEvent sipImportedTypes_QtQuick_QtCore[2].it_td
#define sipClass_QEvent sipImportedTypes_QtQuick_QtCore[2].it_td->u.td_wrapper_type

#define sipType_QTimerEvent sipImportedTypes_QtQuick_QtCore[15].it_td
#define sipClass_QTimerEvent sipImportedTypes_QtQuick_QtCore[15].it_td->u.td_wrapper_type

#define sipType_QChildEvent sipImportedTypes_QtQuick_QtCore[1].it_td
#define sipClass_QChildEvent sipImportedTypes_QtQuick_QtCore[1].it_td->u.td_wrapper_type

#define sipType_QMetaMethod sipImportedTypes_QtQuick_QtCore[3].it_td
#define sipClass_QMetaMethod sipImportedTypes_QtQuick_QtCore[3].it_td->u.td_wrapper_type

#define sipType_QPoint sipImportedTypes_QtQuick_QtCore[5].it_td
#define sipClass_QPoint sipImportedTypes_QtQuick_QtCore[5].it_td->u.td_wrapper_type

#define sipType_QPointF sipImportedTypes_QtQuick_QtCore[6].it_td
#define sipClass_QPointF sipImportedTypes_QtQuick_QtCore[6].it_td->u.td_wrapper_type

#define sipType_QRect sipImportedTypes_QtQuick_QtCore[7].it_td
#define sipClass_QRect sipImportedTypes_QtQuick_QtCore[7].it_td->u.td_wrapper_type

#define sipType_QRectF sipImportedTypes_QtQuick_QtCore[8].it_td
#define sipClass_QRectF sipImportedTypes_QtQuick_QtCore[8].it_td->u.td_wrapper_type

#define sipType_QRunnable sipImportedTypes_QtQuick_QtCore[9].it_td
#define sipClass_QRunnable sipImportedTypes_QtQuick_QtCore[9].it_td->u.td_wrapper_type

#define sipType_QSize sipImportedTypes_QtQuick_QtCore[10].it_td
#define sipClass_QSize sipImportedTypes_QtQuick_QtCore[10].it_td->u.td_wrapper_type

#define sipType_QSizeF sipImportedTypes_QtQuick_QtCore[11].it_td
#define sipClass_QSizeF sipImportedTypes_QtQuick_QtCore[11].it_td->u.td_wrapper_type

#define sipType_QThread sipImportedTypes_QtQuick_QtCore[14].it_td
#define sipClass_QThread sipImportedTypes_QtQuick_QtCore[14].it_td->u.td_wrapper_type

#define sipType_QUrl sipImportedTypes_QtQuick_QtCore[16].it_td
#define sipClass_QUrl sipImportedTypes_QtQuick_QtCore[16].it_td->u.td_wrapper_type

#define sipType_QVariant sipImportedTypes_QtQuick_QtCore[17].it_td
#define sipClass_QVariant sipImportedTypes_QtQuick_QtCore[17].it_td->u.td_wrapper_type

#define sipType_QVector_1800 sipImportedTypes_QtQuick_QtCore[19].it_td

#define sipType_QVariantMap sipImportedTypes_QtQuick_QtCore[18].it_td

#define sipType_QStringList sipImportedTypes_QtQuick_QtCore[13].it_td

#define sipType_QString sipImportedTypes_QtQuick_QtCore[12].it_td
extern sipImportedTypeDef sipImportedTypes_QtQuick_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtQuick_QtCore[];

#define sipType_QQmlEngine sipImportedTypes_QtQuick_QtQml[2].it_td
#define sipClass_QQmlEngine sipImportedTypes_QtQuick_QtQml[2].it_td->u.td_wrapper_type

#define sipType_QQmlContext sipImportedTypes_QtQuick_QtQml[1].it_td
#define sipClass_QQmlContext sipImportedTypes_QtQuick_QtQml[1].it_td->u.td_wrapper_type

#define sipType_QQmlImageProviderBase sipImportedTypes_QtQuick_QtQml[3].it_td
#define sipClass_QQmlImageProviderBase sipImportedTypes_QtQuick_QtQml[3].it_td->u.td_wrapper_type

#define sipType_QQmlImageProviderBase_ImageType sipImportedTypes_QtQuick_QtQml[5].it_td
#define sipEnum_QQmlImageProviderBase_ImageType sipImportedTypes_QtQuick_QtQml[5].it_td->u.td_py_type

#define sipType_QQmlImageProviderBase_Flags sipImportedTypes_QtQuick_QtQml[4].it_td
#define sipClass_QQmlImageProviderBase_Flags sipImportedTypes_QtQuick_QtQml[4].it_td->u.td_wrapper_type

#define sipType_QQmlIncubationController sipImportedTypes_QtQuick_QtQml[6].it_td
#define sipClass_QQmlIncubationController sipImportedTypes_QtQuick_QtQml[6].it_td->u.td_wrapper_type

#define sipType_QQmlParserStatus sipImportedTypes_QtQuick_QtQml[7].it_td
#define sipClass_QQmlParserStatus sipImportedTypes_QtQuick_QtQml[7].it_td->u.td_wrapper_type

#define sipType_QList_0100QQmlError sipImportedTypes_QtQuick_QtQml[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtQuick_QtQml[];

#define sipType_QPixmap sipImportedTypes_QtQuick_QtGui[21].it_td
#define sipClass_QPixmap sipImportedTypes_QtQuick_QtGui[21].it_td->u.td_wrapper_type

#define sipType_QColor sipImportedTypes_QtQuick_QtGui[0].it_td
#define sipClass_QColor sipImportedTypes_QtQuick_QtGui[0].it_td->u.td_wrapper_type

#define sipType_QCursor sipImportedTypes_QtQuick_QtGui[1].it_td
#define sipClass_QCursor sipImportedTypes_QtQuick_QtGui[1].it_td->u.td_wrapper_type

#define sipType_QMouseEvent sipImportedTypes_QtQuick_QtGui[14].it_td
#define sipClass_QMouseEvent sipImportedTypes_QtQuick_QtGui[14].it_td->u.td_wrapper_type

#define sipType_QHoverEvent sipImportedTypes_QtQuick_QtGui[9].it_td
#define sipClass_QHoverEvent sipImportedTypes_QtQuick_QtGui[9].it_td->u.td_wrapper_type

#define sipType_QWheelEvent sipImportedTypes_QtQuick_QtGui[31].it_td
#define sipClass_QWheelEvent sipImportedTypes_QtQuick_QtGui[31].it_td->u.td_wrapper_type

#define sipType_QTabletEvent sipImportedTypes_QtQuick_QtGui[28].it_td
#define sipClass_QTabletEvent sipImportedTypes_QtQuick_QtGui[28].it_td->u.td_wrapper_type

#define sipType_QKeyEvent sipImportedTypes_QtQuick_QtGui[12].it_td
#define sipClass_QKeyEvent sipImportedTypes_QtQuick_QtGui[12].it_td->u.td_wrapper_type

#define sipType_QFocusEvent sipImportedTypes_QtQuick_QtGui[7].it_td
#define sipClass_QFocusEvent sipImportedTypes_QtQuick_QtGui[7].it_td->u.td_wrapper_type

#define sipType_QMoveEvent sipImportedTypes_QtQuick_QtGui[15].it_td
#define sipClass_QMoveEvent sipImportedTypes_QtQuick_QtGui[15].it_td->u.td_wrapper_type

#define sipType_QResizeEvent sipImportedTypes_QtQuick_QtGui[23].it_td
#define sipClass_QResizeEvent sipImportedTypes_QtQuick_QtGui[23].it_td->u.td_wrapper_type

#define sipType_QShowEvent sipImportedTypes_QtQuick_QtGui[24].it_td
#define sipClass_QShowEvent sipImportedTypes_QtQuick_QtGui[24].it_td->u.td_wrapper_type

#define sipType_QHideEvent sipImportedTypes_QtQuick_QtGui[8].it_td
#define sipClass_QHideEvent sipImportedTypes_QtQuick_QtGui[8].it_td->u.td_wrapper_type

#define sipType_QInputMethodEvent sipImportedTypes_QtQuick_QtGui[11].it_td
#define sipClass_QInputMethodEvent sipImportedTypes_QtQuick_QtGui[11].it_td->u.td_wrapper_type

#define sipType_QDropEvent sipImportedTypes_QtQuick_QtGui[5].it_td
#define sipClass_QDropEvent sipImportedTypes_QtQuick_QtGui[5].it_td->u.td_wrapper_type

#define sipType_QDragMoveEvent sipImportedTypes_QtQuick_QtGui[4].it_td
#define sipClass_QDragMoveEvent sipImportedTypes_QtQuick_QtGui[4].it_td->u.td_wrapper_type

#define sipType_QDragEnterEvent sipImportedTypes_QtQuick_QtGui[2].it_td
#define sipClass_QDragEnterEvent sipImportedTypes_QtQuick_QtGui[2].it_td->u.td_wrapper_type

#define sipType_QDragLeaveEvent sipImportedTypes_QtQuick_QtGui[3].it_td
#define sipClass_QDragLeaveEvent sipImportedTypes_QtQuick_QtGui[3].it_td->u.td_wrapper_type

#define sipType_QTouchEvent sipImportedTypes_QtQuick_QtGui[30].it_td
#define sipClass_QTouchEvent sipImportedTypes_QtQuick_QtGui[30].it_td->u.td_wrapper_type

#define sipType_QExposeEvent sipImportedTypes_QtQuick_QtGui[6].it_td
#define sipClass_QExposeEvent sipImportedTypes_QtQuick_QtGui[6].it_td->u.td_wrapper_type

#define sipType_QImage sipImportedTypes_QtQuick_QtGui[10].it_td
#define sipClass_QImage sipImportedTypes_QtQuick_QtGui[10].it_td->u.td_wrapper_type

#define sipType_QMatrix4x4 sipImportedTypes_QtQuick_QtGui[13].it_td
#define sipClass_QMatrix4x4 sipImportedTypes_QtQuick_QtGui[13].it_td->u.td_wrapper_type

#define sipType_QSurface sipImportedTypes_QtQuick_QtGui[25].it_td
#define sipClass_QSurface sipImportedTypes_QtQuick_QtGui[25].it_td->u.td_wrapper_type

#define sipType_QSurface_SurfaceType sipImportedTypes_QtQuick_QtGui[26].it_td
#define sipEnum_QSurface_SurfaceType sipImportedTypes_QtQuick_QtGui[26].it_td->u.td_py_type

#define sipType_QOpenGLContext sipImportedTypes_QtQuick_QtGui[16].it_td
#define sipClass_QOpenGLContext sipImportedTypes_QtQuick_QtGui[16].it_td->u.td_wrapper_type

#define sipType_QOpenGLFramebufferObject sipImportedTypes_QtQuick_QtGui[17].it_td
#define sipClass_QOpenGLFramebufferObject sipImportedTypes_QtQuick_QtGui[17].it_td->u.td_wrapper_type

#define sipType_QOpenGLShader_ShaderType sipImportedTypes_QtQuick_QtGui[18].it_td
#define sipClass_QOpenGLShader_ShaderType sipImportedTypes_QtQuick_QtGui[18].it_td->u.td_wrapper_type

#define sipType_QOpenGLShaderProgram sipImportedTypes_QtQuick_QtGui[19].it_td
#define sipClass_QOpenGLShaderProgram sipImportedTypes_QtQuick_QtGui[19].it_td->u.td_wrapper_type

#define sipType_QWindow sipImportedTypes_QtQuick_QtGui[32].it_td
#define sipClass_QWindow sipImportedTypes_QtQuick_QtGui[32].it_td->u.td_wrapper_type

#define sipType_QPainter sipImportedTypes_QtQuick_QtGui[20].it_td
#define sipClass_QPainter sipImportedTypes_QtQuick_QtGui[20].it_td->u.td_wrapper_type

#define sipType_QRegion sipImportedTypes_QtQuick_QtGui[22].it_td
#define sipClass_QRegion sipImportedTypes_QtQuick_QtGui[22].it_td->u.td_wrapper_type

#define sipType_QSurfaceFormat sipImportedTypes_QtQuick_QtGui[27].it_td
#define sipClass_QSurfaceFormat sipImportedTypes_QtQuick_QtGui[27].it_td->u.td_wrapper_type

#define sipType_QTextDocument sipImportedTypes_QtQuick_QtGui[29].it_td
#define sipClass_QTextDocument sipImportedTypes_QtQuick_QtGui[29].it_td->u.td_wrapper_type
extern sipImportedTypeDef sipImportedTypes_QtQuick_QtGui[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *,sipTypeDef *);
extern sip_qt_metaobject_func sip_QtQuick_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *,sipTypeDef *,QMetaObject::Call,int,void **);
extern sip_qt_metacall_func sip_QtQuick_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtQuick_qt_metacast;
#line 316 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickwindow.sip"
#include "qpyquick_api.h"
#line 2918 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipAPIQtQuick.h"

#endif
